@@ -43,13 +43,11 @@ string Configuration::s_savePath = "./saves/";
 #endif
 string Configuration::s_lang = "";
 int Configuration::s_displaySpeedDelay = 0;
-Uint32 Configuration::s_flags = 0;
 Uint32 Configuration::s_surfaceFlags = SDL_SWSURFACE;
 Uint32 Configuration::s_cacheSize = 1000000;
 bool Configuration::s_zipfiles = false;
 bool Configuration::s_hardware = false;
 bool Configuration::s_ggz = false;
-bool Configuration::s_fullScreen = false;
 bool Configuration::s_musicenable = true;
 Uint32 Configuration::s_musicvolume = 64;
 Uint32 Configuration::s_musiccache = 10000000;
@@ -60,10 +58,12 @@ bool Configuration::s_play_with_quests = true;
 bool Configuration::s_hidden_map = false;
 bool Configuration::s_diplomacy = false;
 GameParameters::NeutralCities Configuration::s_neutral_cities = GameParameters::AVERAGE;
+GameParameters::RazingCities Configuration::s_razing_cities = GameParameters::ALWAYS;
 bool Configuration::s_intense_combat = false;
 bool Configuration::s_military_advisor = false;
 bool Configuration::s_random_turns = false;
 bool Configuration::s_quick_start = false;
+bool Configuration::s_cusp_of_war = false;
 
 Configuration::Configuration()
 {
@@ -113,7 +113,6 @@ bool Configuration::saveConfigurationFile(string filename)
     retval &= helper.saveData("datapath",s_dataPath);
     retval &= helper.saveData("savepath", s_savePath);
     retval &= helper.saveData("lang", s_lang);
-    retval &= helper.saveData("fullscreen", s_fullScreen);
     retval &= helper.saveData("cachesize", s_cacheSize);
     retval &= helper.saveData("hardware", s_hardware);
     retval &= helper.saveData("zipfiles", s_zipfiles);
@@ -128,10 +127,12 @@ bool Configuration::saveConfigurationFile(string filename)
     retval &= helper.saveData("hidden_map", s_hidden_map);
     retval &= helper.saveData("diplomacy", s_diplomacy);
     retval &= helper.saveData("neutral_cities", (int) s_neutral_cities);
+    retval &= helper.saveData("razing_cities", (int) s_razing_cities);
     retval &= helper.saveData("intense_combat", s_intense_combat);
     retval &= helper.saveData("military_advisor", s_military_advisor);
     retval &= helper.saveData("random_turns", s_random_turns);
     retval &= helper.saveData("quick_start", s_quick_start);
+    retval &= helper.saveData("cusp_of_war", s_cusp_of_war);
     retval &= helper.closeTag();
     
     if (!retval)
@@ -203,20 +204,6 @@ bool Configuration::parseConfiguration(string tag, XML_Helper* helper)
     if (helper->getData(temp, "lang"))
         s_lang = temp;
     
-    //fullscreen?
-    retval = helper->getData(s_fullScreen, "fullscreen");
-    if (retval)
-    {
-        if (s_fullScreen)
-        {
-            s_flags |= SDL_FULLSCREEN;
-        }
-        else
-        {
-            s_flags &= ~SDL_FULLSCREEN;
-        }
-    }
-
     //parse cache size
     retval = helper->getData(temp, "cachesize");
     if (retval)
@@ -262,10 +249,14 @@ bool Configuration::parseConfiguration(string tag, XML_Helper* helper)
     int val = -1;
     helper->getData(val, "neutral_cities");
     s_neutral_cities = GameParameters::NeutralCities (val);
+    val = -1;
+    helper->getData(val, "razing_cities");
+    s_razing_cities = GameParameters::RazingCities (val);
     helper->getData(s_intense_combat, "intense_combat");
     helper->getData(s_military_advisor, "military_advisor");
     helper->getData(s_random_turns, "random_turns");
     helper->getData(s_quick_start, "quick_start");
+    helper->getData(s_cusp_of_war, "cusp_of_war");
     return true;
 }
 
