@@ -136,33 +136,41 @@ SDL_Surface* File::getArmyPicture(string armysetname, string pic)
 }
 
 
-string File::getMapset(string mapsetname)
+string File::getTileset(string tilesetname)
 {
-    return Configuration::s_dataPath + "/tilesets/" + mapsetname + "/" + mapsetname + ".xml";
+    return Configuration::s_dataPath + "/tilesets/" + tilesetname + "/" + tilesetname + ".xml";
 }
 
-std::string File::getMapsetFile(string mapsetname, string picname)
+std::string File::getTilesetFile(string tilesetname, string picname)
 {
-    return Configuration::s_dataPath + "/tilesets/" + mapsetname + "/" + picname;
+    return Configuration::s_dataPath + "/tilesets/" + tilesetname + "/" + picname;
 }
 
-SDL_Surface* File::getMapsetPicture(string mapsetname, string picname)
+SDL_Surface* File::getTilesetPicture(string tilesetname, string picname)
 {
-    return loadImage(getMapsetFile(mapsetname, picname));
+    return loadImage(getTilesetFile(tilesetname, picname));
 }
 
-SDL_Surface* File::getMapsetMask(string mapsetname, string picname)
-{
-    string filename = Configuration::s_dataPath + "/tilesets/" + mapsetname + "/" + picname;
-    return IMG_Load(filename.c_str());
-}
-
-
 string File::getMiscFile(string filename)
 {
     return Configuration::s_dataPath + "/" + filename;
 }
 
+string File::getCityset(string citysetname)
+{
+    return Configuration::s_dataPath + "/citysets/" + citysetname + "/" + citysetname + ".xml";
+}
+
+std::string File::getCitysetFile(string citysetname, string picname)
+{
+    return Configuration::s_dataPath + "/citysets/" + citysetname + "/" + picname;
+}
+
+SDL_Surface* File::getCitysetPicture(string citysetname, string picname)
+{
+    return loadImage(getCitysetFile(citysetname, picname));
+}
+
 SDL_Surface* File::getMiscPicture(string picname, bool alpha)
 {
     return loadImage(Configuration::s_dataPath + "/various/" + picname,alpha);
@@ -216,6 +224,22 @@ list<string> File::scanTilesets()
     return retlist;
 }
 
+list<string> File::scanCitysets()
+{
+    string path = Configuration::s_dataPath + "/citysets/";
+    std::list<std::string> retlist = get_xml_files_in_immediate_subdirs(path);
+    
+    if (retlist.empty())
+    {
+        cerr << _("Couldn't find any citysets!") << endl;
+        cerr << _("Please check the path settings in /etc/lordsawarrc or ~/.lordsawarrc") << endl;
+        cerr << _("Exiting!") << endl;
+        exit(-1);
+    }
+    
+    return retlist;
+}
+
 list<string> File::scanMaps()
 {
     string path = Configuration::s_dataPath + "/map/";
@@ -243,4 +267,33 @@ list<string> File::scanMaps()
 }
 
 
+std::list<std::string> File::scanShieldsets()
+{
+    string path = Configuration::s_dataPath + "/shield/";
+
+    std::list<std::string> retlist = get_xml_files_in_immediate_subdirs(path);
+
+    if (retlist.empty())
+    {
+        cerr << _("Couldn't find any shieldsets!") << endl;
+        cerr << _("Please check the path settings in /etc/lordsawarrc or ~/.lordsawarrc") << endl;
+        cerr << _("Exiting!") << endl;
+        exit(-1);
+    }
+
+    return retlist;
+}
+
+
+string File::getShieldset(string shieldsetname)
+{
+    return Configuration::s_dataPath + "/shield/" + shieldsetname + "/" + 
+      shieldsetname + ".xml";
+}
+
+SDL_Surface* File::getShieldPicture(string shieldsetname, string pic)
+{
+    return loadImage(Configuration::s_dataPath + "/shield/" + shieldsetname + "/" + pic);
+}
+
 // End of file
