@@ -47,40 +47,69 @@ class File
 
         /** Get the armyset picture file
           * 
-          * @param amysetname       the name of the armyset
+          * @param armysetname       the name of the armyset
+	  * @param pic               the name of the army picture 
           * @return the surface which contains the army pictures of this armyset
           */
         static SDL_Surface* getArmyPicture(std::string armysetname, std::string pic);
+
+        /** Scan the data directories for shieldsets
+          * 
+          * @return a list of available shieldsets
+          */
+        static std::list<std::string> scanShieldsets();
+
+        /** Get the shieldset description file
+          *
+          * @param shieldsetname      the name of the shieldset
+          * @return the full name of the shield description file
+          */
+        static std::string getShieldset(std::string shieldsetname);
+
+        /** Get the shield picture file
+          * 
+          * @param shieldsetname       the name of the shieldset
+	  * @param pic                 the name of the shield picture
+          * @return the surface which contains the shield picture
+          */
+        static SDL_Surface* getShieldPicture(std::string armysetname, std::string pic);
         
         
 
-        /** Get the description file for the mapset
+        /** Get the description file for the tileset
           * 
-          * @param mapsetname       the name of the mapset
+          * @param tilesetname       the name of the tileset
           * @return the full name of the description file
           */
-        static std::string getMapset(std::string mapsetname);
+        static std::string getTileset(std::string tilesetname);
 
-        /** Get a mapset picture
-          * @param mapsetname       the name of the mapset
+        /** Get a tileset picture
+          * @param tilesetname       the name of the tileset
           * @param picname          the name of the picture
           * @return the surface which contains the picture
           */
-        static SDL_Surface* getMapsetPicture(std::string mapsetname, std::string picname);
+        static SDL_Surface* getTilesetPicture(std::string tilesetname, std::string picname);
 
-	// get a mapset path
-	static std::string getMapsetFile(std::string mapsetname, std::string picname);
+	// get a tileset path
+	static std::string getTilesetFile(std::string tilesetname, std::string picname);
 	
-        /** Load a mask needed by various mapset images (e.g. cities)
+        /** Get the description file for the cityset
           * 
-          * @param mapsetname       the name of the mapset
-          * @param picname          the name of the mask picture
-          * @return the surface which contains the surface for the mask
+          * @param citysetname       the name of the cityset
+          * @return the full name of the description file
           */
-        static SDL_Surface* getMapsetMask(std::string mapsetname, std::string picname);
+        static std::string getCityset(std::string citysetname);
 
-        
-        
+        /** Get a cityset picture
+          * @param citysetname       the name of the cityset
+          * @param picname          the name of the picture
+          * @return the surface which contains the picture
+          */
+        static SDL_Surface* getCitysetPicture(std::string citysetname, std::string picname);
+
+	// get a cityset path
+	static std::string getCitysetFile(std::string citysetname, std::string picname);
+	
         //! load misc file, e.g. hero names 
         static std::string getMiscFile(std::string filename);
         
@@ -118,6 +147,9 @@ class File
         // get the available tilesets
         static std::list<std::string> scanTilesets();
 
+        // get the available citysets
+        static std::list<std::string> scanCitysets();
+
         // get the available maps
         static std::list<std::string> scanMaps();
 
