@@ -20,6 +20,7 @@
 #include "citylist.h"
 #include "bridgelist.h"
 #include "portlist.h"
+#include "roadlist.h"
 #include "city.h"
 #include "ruin.h"
 #include "temple.h"
@@ -30,6 +31,8 @@
 #include "xmlhelper.h"
 #include "MapGenerator.h"
 #include "tilesetlist.h"
+#include "shieldsetlist.h"
+#include "citysetlist.h"
 
 using namespace std;
 
@@ -50,11 +53,13 @@ GameMap* GameMap::getInstance()
 }
 
 
-GameMap* GameMap::getInstance(std::string TilesetName)
+GameMap* GameMap::getInstance(std::string TilesetName, 
+			      std::string ShieldsetName, 
+			      std::string CitysetName)
 {
     if (s_instance == 0)
     {
-        s_instance = new GameMap(TilesetName);
+        s_instance = new GameMap(TilesetName, ShieldsetName, CitysetName);
 
     }
     return s_instance;
@@ -77,9 +82,12 @@ void GameMap::deleteInstance()
     s_instance = 0;
 }
 
-GameMap::GameMap(std::string TilesetName)
+GameMap::GameMap(std::string TilesetName, std::string ShieldsetName,
+		 std::string CitysetName)
 {
     d_tileSet = Tilesetlist::getInstance()->getTileset(TilesetName);
+    d_shieldSet = Shieldsetlist::getInstance()->getShieldset(ShieldsetName);
+    d_citySet = Citysetlist::getInstance()->getCityset(CitysetName);
 
     d_map = new Maptile*[s_width*s_height];
     for (int j = 0; j < s_height; j++)
@@ -93,14 +101,20 @@ GameMap::GameMap(XML_Helper* helper)
     std::string types;
     std::string styles;
     std::string t_dir;
+    std::string s_dir;
+    std::string c_dir;
 
     helper->getData(s_width, "width");
     helper->getData(s_height, "height");
     helper->getData(t_dir,"tileset");
+    helper->getData(s_dir,"shieldset");
+    helper->getData(c_dir,"cityset");
     helper->getData(types, "types");
     helper->getData(styles, "styles");
 
     d_tileSet = Tilesetlist::getInstance()->getTileset(t_dir);
+    d_shieldSet = Shieldsetlist::getInstance()->getShieldset(s_dir);
+    d_citySet = Citysetlist::getInstance()->getCityset(c_dir);
 
     //create the map
     d_map = new Maptile*[s_width*s_height];
@@ -258,6 +272,8 @@ bool GameMap::save(XML_Helper* helper) const
     retval &= helper->saveData("width", s_width);
     retval &= helper->saveData("height", s_height);
     retval &= helper->saveData("tileset", d_tileSet->getSubDir());
+    retval &= helper->saveData("shieldset", d_shieldSet->getSubDir());
+    retval &= helper->saveData("cityset", d_citySet->getSubDir());
     retval &= helper->saveData("types", types.str());
     retval &= helper->saveData("styles", styles.str());
 
@@ -303,6 +319,12 @@ bool GameMap::loadItems(std::string tag, XML_Helper* helper)
     return true;
 }
 
+void GameMap::setTile(int x, int y, Maptile *tile)
+{
+    delete d_map[y*s_width + x];
+    d_map[y*s_width + x] = tile;
+}
+
 Maptile* GameMap::getTile(int x, int y) const
 {
     assert(x >= 0 && x < s_width && y >= 0 && y < s_height);
@@ -370,7 +392,7 @@ Stack* GameMap::addArmyAtPos(Vector<int> pos, Army *a)
                   y = pos.y + (j - d);
                   if (x < 0 || y < 0)
                     continue;
-                  if (x > s_width || y > s_height)
+                  if (x >= s_width || y >= s_height)
                     continue;
                   //is there somebody else's city here?
                   City *c = Citylist::getInstance()->getObjectAt(x, y);
@@ -391,7 +413,7 @@ Stack* GameMap::addArmyAtPos(Vector<int> pos, Army *a)
                       if (s->getPlayer() != a->getPlayer())
                         continue;
                       //is it our stack, but too full?
-                      if (s->size() >= 8)
+                      if (s->size() >= MAX_STACK_SIZE)
                         continue;
                     }
                   //hey this looks like a good place for a stack
@@ -458,59 +480,77 @@ bool GameMap::isBlockedAvenue(int x, int y, int destx, int desty)
       Maptile *to = getTile(destx, desty);
       if (from == to)
         return false;
-      //am i on water going towards land that isn't a city?
+      //am i on land, going towards water that has a port on it?
+      //if (from->getMaptileType() != Tile::WATER &&
+          //to->getMaptileType() == Tile::WATER &&
+          //to_dock)
+        //return false;
+      //am i on water going towards land from a port?
+      //if (from->getMaptileType() == Tile::WATER &&
+          //to->getMaptileType() != Tile::WATER &&
+          //from_dock)
+        //return false;
+
+      //am i on water going towards land that isn't a city,
+      //and i'm not coming from a port
       if (from->getMaptileType() == Tile::WATER &&
           to->getMaptileType() != Tile::WATER &&
-          !to_dock)
+          !to_dock && !from_dock)
         return true;
-      //am i on land, going towards water from a tile that isn't a city?
+
+      //am i on land, going towards water from a tile that isn't a
+      //city, or a port and i'm not going to a port?
       if (from->getMaptileType() != Tile::WATER &&
           to->getMaptileType() == Tile::WATER &&
-          !from_dock)
+          !from_dock && !to_dock)
         return true;
-      //is the tile i'm going to a mountain?
-      if (to->getMaptileType() == Tile::MOUNTAIN)
+
+      //is the tile i'm going to a mountain that doesn't have a road?
+      if (to->getMaptileType() == Tile::MOUNTAIN &&
+	  Roadlist::getInstance()->getObjectAt(destx, desty) == NULL)
         return true;
     }
  return false;
 }
 
-void GameMap::calculateBlockedAvenues()
+void GameMap::calculateBlockedAvenue(int i, int j)
 {
   int diffx = 0, diffy = 0;
   int destx = 0, desty = 0;
+  Maptile *maptile = getTile(i, j);
+  for (int k = 0; k < 8; k++)
+    {
+      switch (k)
+	{
+	case 0: diffx = -1;  diffy = -1; break;
+	case 1: diffx = -1; diffy = 0; break;
+	case 2: diffx = -1; diffy = 1; break;
+	case 3: diffx = 0; diffy = 1; break;
+	case 4: diffx = 0; diffy = -1; break;
+	case 5: diffx = 1; diffy = -1; break;
+	case 6: diffx = 1; diffy = 0; break;
+	case 7: diffx = 1; diffy = 1; break;
+	}
+      destx = i + diffx;
+      desty = j + diffy;
+      if (destx < 0 || destx >= s_width)
+	{
+	  maptile->d_blocked[k] = true;
+	  continue;
+	}
+      if (desty < 0 || desty >= s_height)
+	{
+	  maptile->d_blocked[k] = true;
+	  continue;
+	}
+      maptile->d_blocked[k] = isBlockedAvenue(i, j, destx, desty);
+    }
+}
+void GameMap::calculateBlockedAvenues()
+{
   for (int i = 0; i < s_width; i++)
     for (int j = 0; j < s_height; j++)
-      {
-        Maptile *maptile = getTile(i, j);
-        for (int k = 0; k < 8; k++)
-          {
-            switch (k)
-              {
-                case 0: diffx = -1;  diffy = -1; break;
-                case 1: diffx = -1; diffy = 0; break;
-                case 2: diffx = -1; diffy = 1; break;
-                case 3: diffx = 0; diffy = 1; break;
-                case 4: diffx = 0; diffy = -1; break;
-                case 5: diffx = 1; diffy = -1; break;
-                case 6: diffx = 1; diffy = 0; break;
-                case 7: diffx = 1; diffy = 1; break;
-              }
-              destx = i + diffx;
-              desty = j + diffy;
-              if (destx < 0 || destx >= s_width)
-                {
-                  maptile->d_blocked[k] = true;
-                  continue;
-                }
-              if (desty < 0 || desty >= s_height)
-                {
-                  maptile->d_blocked[k] = true;
-                  continue;
-                }
-              maptile->d_blocked[k] = isBlockedAvenue(i, j, destx, desty);
-          }
-      }
+      calculateBlockedAvenue(i, j);
 }
 
 Vector<int> GameMap::findPlantedStandard(Player *p)
@@ -545,7 +585,7 @@ Vector<int> GameMap::findPlantedStandard(Player *p)
 
 TileStyle *GameMap::calculatePreferredStyle(int i, int j)
 {
-  TileSet *tileset = getTileSet();
+  Tileset *tileset = getTileset();
   Maptile *mtile = getTile(j, i);
   int box[3][3];
   for (int k = -1; k <= +1; k++)
@@ -638,14 +678,14 @@ TileStyle *GameMap::calculatePreferredStyle(int i, int j)
 
 void GameMap::close_circles (int minx, int miny, int maxx, int maxy)
 {
-  TileSet *tileset = getTileSet();
+  Tileset *tileset = getTileset();
   for (int i = minx; i < maxx; i++)
     {
       for (int j = miny; j < maxy; j++)
 	{
-	  if (i < 0 || i > s_height)
+	  if (i < 0 || i >= s_height)
 	    continue;
-	  if (j < 0 || j > s_width)
+	  if (j < 0 || j >= s_width)
 	    continue;
 	  Maptile *tile = getTile(j, i);
 	  TileStyle *tilestyle = tile->getTileStyle();
@@ -740,6 +780,10 @@ void GameMap::demote_lone_tile(int minx, int miny, int maxx, int maxy,
   for (i = minx; i < maxx; i++)
     for (j = miny; j < maxy; j++)
       {
+	if (i < 0 || i >= s_height)
+	  continue;
+	if (j < 0 || j >= s_width)
+	  continue;
 	Tile::Type tile = d_map[i*s_width + j]->getMaptileType();
 	if (tile == intype)
 	  {
@@ -776,12 +820,12 @@ void GameMap::applyTileStyles (int minx, int miny, int maxx, int maxy,
     {
       for (int j = miny; j < maxy; j++)
 	{
-	  if (i < 0 || i > s_height)
+	  if (i < 0 || i >= s_height)
 	    continue;
-	  if (j < 0 || j > s_width)
+	  if (j < 0 || j >= s_width)
 	    continue;
 	  Maptile *mtile = getTile(j, i);
-	  TileSet *tileset = getTileSet();
+	  Tileset *tileset = getTileset();
 	  TileStyle *style = calculatePreferredStyle(i, j);
 	  if (!style)
 	    style = tileset->getRandomTileStyle(mtile->getType(), 
