@@ -22,6 +22,8 @@
 #include "maptile.h"
 #include "stack.h"
 #include "Location.h"
+#include "shieldset.h"
+#include "cityset.h"
 
 class MapGenerator;
 class XML_Helper;
@@ -51,7 +53,9 @@ class GameMap: public sigc::trackable
           * @param TilesetName      the name of the tileset to be used
           * @return singleton instance
           */
-        static GameMap* getInstance(std::string TilesetName);
+        static GameMap* getInstance(std::string TilesetName,
+				    std::string Shieldsetname,
+				    std::string Citysetname);
 
         /** Creates a new singleton instance from a savegame file
           * 
@@ -83,8 +87,20 @@ class GameMap: public sigc::trackable
 	    { return Rectangle(0, 0, s_width, s_height); }
 
         //! Returns the tileset in use
-        TileSet* getTileSet() const {return d_tileSet;}
+        Tileset* getTileset() const {return d_tileSet;}
+
+        //! Returns the shieldset in use
+        Shieldset* getShieldset() const {return d_shieldSet;}
+
+        //! Returns the tileset in use
+        Cityset* getCityset() const {return d_citySet;}
+
+	//! Sets the tile object at position (x, y)
+	void setTile(int x, int y, Maptile *tile);
         
+        //! Alternative setting
+        void setTile(Vector<int> p, Maptile *t) {return setTile(p.x, p.y, t);}
+
         //! Get the tile object at position (x,y)
         Maptile* getTile(int x, int y) const;
 
@@ -121,6 +137,7 @@ class GameMap: public sigc::trackable
 
 	//! figure out where a non-flying unit can't go
         void calculateBlockedAvenues();
+	void calculateBlockedAvenue(int i, int j);
 
 	/** Smooth a portion of the map.
 	 *
@@ -132,7 +149,8 @@ class GameMap: public sigc::trackable
 
     protected:
         //! Create the map with the given tileset
-        GameMap(std::string TilesetName);
+        GameMap(std::string TilesetName, std::string ShieldsetName,
+		std::string Citysetname);
 
         //! Load the map using the given XML_Helper
         GameMap(XML_Helper* helper);
@@ -148,7 +166,7 @@ class GameMap: public sigc::trackable
 	void close_circles (int minx, int miny, int maxx, int maxy);
 
 	TileStyle *calculatePreferredStyle(int i, int j);
-	void demote_lone_tile(int minx, int miny, int minx, int miny, 
+	void demote_lone_tile(int minx, int miny, int maxx, int maxy, 
 			      Tile::Type intype, Tile::Type outtype);
 	int tile_is_connected_to_other_like_tiles (Tile::Type tile, int i, 
 						   int j);
@@ -158,7 +176,9 @@ class GameMap: public sigc::trackable
         static int s_width;
         static int s_height;
 
-        TileSet* d_tileSet;
+        Tileset* d_tileSet;
+        Shieldset* d_shieldSet;
+        Cityset* d_citySet;
         Maptile** d_map;
 };
 
