@@ -18,6 +18,7 @@
 
 #include "GraphicsCache.h"
 #include "armysetlist.h"
+#include "shieldsetlist.h"
 #include "army.h"
 #include "playerlist.h"
 #include "Configuration.h"
@@ -142,8 +143,9 @@ struct SelectorCacheItem
 // the structure to store shield images in
 struct ShieldCacheItem
 {
+    std::string shieldset;
     Uint32 type;
-    const Player* player;
+    Uint32 colour;
     SDL_Surface* surface;
 };
 
@@ -196,7 +198,6 @@ GraphicsCache::GraphicsCache()
     loadCursorPics();
     loadFlags();
     loadSelectors();
-    loadShields();
     loadProdShields();
     loadMoveBonusPics();
 
@@ -208,8 +209,11 @@ GraphicsCache::GraphicsCache()
       File::getMiscPicture("smallunexploredstronghold.png");
     d_small_ruin_explored = File::getMiscPicture("smallexploredruin.png");
     d_small_temple = File::getMiscPicture("smalltemple.png");
-    std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
-    d_port = File::getMapsetPicture(tileset, "misc/port.png");
+    std::string tileset = GameMap::getInstance()->getTileset()->getSubDir();
+    std::string cityset = GameMap::getInstance()->getCityset()->getSubDir();
+    d_port = File::getCitysetPicture(cityset, "port.png");
+    d_explosion = File::getTilesetPicture(tileset, "misc/explosion.png");
+    d_signpost = File::getCitysetPicture(cityset, "signpost.png");
 }
 
 GraphicsCache::~GraphicsCache()
@@ -231,7 +235,7 @@ GraphicsCache::~GraphicsCache()
             SDL_FreeSurface(d_towerpic[i]);
     }
 
-    for (int i = 0; i < 8; i++)
+    for (unsigned int i = 0; i < MAX_STACK_SIZE; i++)
     {
         SDL_FreeSurface(d_flagpic[i]);
         SDL_FreeSurface(d_flagmask[i]);
@@ -249,15 +253,6 @@ GraphicsCache::~GraphicsCache()
         SDL_FreeSurface(d_smallselectormask[i]);
     }
 
-    for (int i = 0; i < 2; i++)
-    {
-      for (unsigned int j = 0; j < MAX_PLAYERS + 1; j++)
-	{
-          SDL_FreeSurface(d_shieldpic[i][j]);
-          SDL_FreeSurface(d_shieldmask[i][j]);
-	}
-    }
-
     for (int i = 0; i < 7; i++)
     {
         SDL_FreeSurface(d_prodshieldpic[i]);
@@ -281,6 +276,8 @@ GraphicsCache::~GraphicsCache()
     SDL_FreeSurface(d_small_stronghold_unexplored);
     SDL_FreeSurface(d_small_ruin_explored);
     SDL_FreeSurface(d_port);
+    SDL_FreeSurface(d_explosion);
+    SDL_FreeSurface(d_signpost);
 }
 
 SDL_Surface* GraphicsCache::getSmallRuinedCityPic()
@@ -315,6 +312,16 @@ SDL_Surface* GraphicsCache::getPortPic()
   return d_port;
 }
 
+SDL_Surface* GraphicsCache::getExplosionPic()
+{
+  return d_explosion;
+}
+
+SDL_Surface* GraphicsCache::getSignpostPic()
+{
+  return d_signpost;
+}
+
 SDL_Surface* GraphicsCache::getMoveBonusPic(Uint32 bonus, bool has_ship)
 {
   Uint32 type;
@@ -452,6 +459,43 @@ SDL_Surface* GraphicsCache::getArmyPic(Uint32 armyset, Uint32 army, const Player
     return myitem->surface;
 }
 
+SDL_Surface* GraphicsCache::getShieldPic(std::string shieldset, 
+					 Uint32 type, 
+					 Uint32 colour)
+{
+    debug("getting shield pic " <<shieldset <<" " <<type <<" " <<colour)
+
+    std::list<ShieldCacheItem*>::iterator it;
+    ShieldCacheItem* myitem;
+
+    for (it =d_shieldlist.begin(); it != d_shieldlist.end(); it++)
+    {
+        if ((*it)->shieldset == shieldset && (*it)->type == type
+            && (*it)->colour == colour)
+        {
+            myitem = (*it);
+            
+            // put the item on the last place (==last touched)
+            d_shieldlist.erase(it);
+            d_shieldlist.push_back(myitem);
+            
+            return myitem->surface;
+        }
+    }
+
+    // We are still here, so the graphic is not in the cache. addShieldPic calls
+    // checkPictures on its own, so we can simply return the surface
+    myitem = addShieldPic(shieldset, type, colour);
+
+    return myitem->surface;
+}
+        
+SDL_Surface* GraphicsCache::getShieldPic(Uint32 type, Player *p)
+{
+  std::string shieldset = GameMap::getInstance()->getShieldset()->getSubDir();
+  return getShieldPic(shieldset, type, p->getId());
+}
+
 SDL_Surface* GraphicsCache::getTemplePic(int type)
 {
     debug("GraphicsCache::getTemplePic " <<type)
@@ -733,37 +777,6 @@ SDL_Surface* GraphicsCache::getSelectorPic(Uint32 type, Uint32 frame,
     return myitem->surface;
 }
 
-SDL_Surface* GraphicsCache::getShieldPic(Uint32 type, const Player *p)
-{
-    debug("GraphicsCache::getShieldPic " <<type <<", " << ", player" <<s->getPlayer()->getName())
-
-    if (!p)
-    {
-        std::cerr <<_("GraphicsCache::getShieldPic: no player supplied! Exiting...\n");
-        exit(-1);
-    }
-    
-    std::list<ShieldCacheItem*>::iterator it;
-    ShieldCacheItem* myitem;
-
-    for (it = d_shieldlist.begin(); it != d_shieldlist.end(); it++)
-    {
-        myitem = *it;
-        if ((myitem->type == type) && (myitem->player == p))
-        {
-            // put the item in last place (last touched)
-            d_shieldlist.erase(it);
-            d_shieldlist.push_back(myitem);
-
-            return myitem->surface;
-        }
-    }
-
-    // no item found => create a new one
-    myitem = addShieldPic(type, p);
-
-    return myitem->surface;
-}
 
 SDL_Surface* GraphicsCache::getProdShieldPic(Uint32 type, bool prod)
 {
@@ -997,6 +1010,39 @@ ArmyCacheItem* GraphicsCache::addArmyPic(Uint32 armyset, Uint32 army,
   return myitem;
 }
 
+ShieldCacheItem* GraphicsCache::addShieldPic(std::string shieldset, 
+					     Uint32 type, Uint32 colour)
+{
+  debug("ADD shield pic: " <<shieldset <<"," <<type <<"," <<colour)
+
+    ShieldCacheItem* myitem = new ShieldCacheItem();
+  myitem->shieldset = shieldset;
+  myitem->type = type;
+  myitem->colour = colour;
+
+  const Shield* shield;
+  shield = Shieldsetlist::getInstance()->getShield(shieldset, type, colour);
+
+  // copy the pixmap including player colors
+  myitem->surface = applyMask(shield->getPixmap(), shield->getMask(), 
+			      Playerlist::getInstance()->getPlayer(colour));
+
+  //now the final preparation steps:
+  //a) add the size
+  int size = myitem->surface->w * myitem->surface->h;
+  d_cachesize += myitem->surface->format->BytesPerPixel * size;
+
+  //b) add the entry to the list
+  d_shieldlist.push_back(myitem);
+
+  //c) check if the cache size is too large
+  checkPictures();
+
+  //we are finished, so return the pic
+  return myitem;
+}
+
+
 ShipCacheItem* GraphicsCache::addShipPic(const Player* p)
 {
   debug("ADD ship pic: " <<p->getName())
@@ -1063,7 +1109,7 @@ PlantedStandardCacheItem* GraphicsCache::addPlantedStandardPic(const Player* p)
 
 TempleCacheItem* GraphicsCache::addTemplePic(int type)
 {
-  //    int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+  //    int ts = GameMap::getInstance()->getTileset()->getTileSize();
 
   SDL_Surface* mysurf = SDL_DisplayFormatAlpha(d_templepic[type]);
 
@@ -1130,7 +1176,7 @@ DiplomacyCacheItem* GraphicsCache::addDiplomacyPic(int type, Player::DiplomaticS
 
 RoadCacheItem* GraphicsCache::addRoadPic(int type)
 {
-  //    int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+  //    int ts = GameMap::getInstance()->getTileset()->getTileSize();
 
   SDL_Surface* mysurf = SDL_DisplayFormatAlpha(d_roadpic[type]);
 
@@ -1175,7 +1221,7 @@ FogCacheItem* GraphicsCache::addFogPic(int type)
 
 BridgeCacheItem* GraphicsCache::addBridgePic(int type)
 {
-  //    int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+  //    int ts = GameMap::getInstance()->getTileset()->getTileSize();
 
   SDL_Surface* mysurf = SDL_DisplayFormatAlpha(d_bridgepic[type]);
 
@@ -1315,35 +1361,6 @@ SelectorCacheItem* GraphicsCache::addSelectorPic(Uint32 type, Uint32 frame, cons
   return myitem;
 }
 
-ShieldCacheItem* GraphicsCache::addShieldPic(Uint32 type, const Player* p)
-{
-  debug("GraphicsCache::addShieldPic, player="<<p->getName()<<", type="<<type);
-  // type is 0 for small, 1 for medium, 2 for large
-
-  assert(type < 3 && p->getId() <= MAX_PLAYERS);
-
-  SDL_Surface* mysurf;
-  mysurf = applyMask(d_shieldpic[type][p->getId()], 
-		     d_shieldmask[type][p->getId()], p);
-
-  //now create the cache item and add the size
-  ShieldCacheItem* myitem = new ShieldCacheItem();
-  myitem->player = p;
-  myitem->type = type;
-  myitem->surface = mysurf;
-
-  d_shieldlist.push_back(myitem);
-
-  //add the size
-  int picsize = mysurf->w * mysurf->h;
-  d_cachesize += picsize * mysurf->format->BytesPerPixel;
-
-  //and check the size of the cache
-  checkPictures();
-
-  return myitem;
-}
-
 ProdShieldCacheItem* GraphicsCache::addProdShieldPic(Uint32 type, bool prod)
 {
   debug("GraphicsCache::addProdShieldPic, prod="<<prod<<", type="<<type)
@@ -1739,12 +1756,12 @@ void GraphicsCache::eraseLastMoveBonusItem()
 
 void GraphicsCache::loadTemplePics()
 {
-  // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
-  int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+  // GameMap has the actual cityset stored
+  std::string cityset = GameMap::getInstance()->getCityset()->getSubDir();
+  int ts = GameMap::getInstance()->getCityset()->getTileSize();
 
   // load the temple pictures
-  SDL_Surface* templepics = File::getMapsetPicture(tileset, "misc/temples.png");
+  SDL_Surface* templepics = File::getCitysetPicture(cityset, "temples.png");
 
   // copy alpha values, don't use them
   SDL_SetAlpha(templepics, 0, 0);
@@ -1775,12 +1792,12 @@ void GraphicsCache::loadTemplePics()
 
 void GraphicsCache::loadRuinPics()
 {
-  // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
-  int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+  // GameMap has the actual cityset stored
+  std::string cityset = GameMap::getInstance()->getCityset()->getSubDir();
+  int ts = GameMap::getInstance()->getCityset()->getTileSize();
 
   // load the ruin pictures
-  SDL_Surface* ruinpics = File::getMapsetPicture(tileset, "misc/ruin.png");
+  SDL_Surface* ruinpics = File::getCitysetPicture(cityset, "ruin.png");
 
   // copy alpha values, don't use them
   SDL_SetAlpha(ruinpics, 0, 0);
@@ -1812,10 +1829,8 @@ void GraphicsCache::loadRuinPics()
 void GraphicsCache::loadDiplomacyPics()
 {
   // load the diplomacy pictures
-  // crapola
-  Uint32 ts;
   SDL_Surface* diplomacypics = File::getMiscPicture("diplomacy-small.png");
-  ts = 30;
+  Uint32 ts = 30;
 
   // copy alpha values, don't use them
   SDL_SetAlpha(diplomacypics, 0, 0);
@@ -1874,11 +1889,11 @@ void GraphicsCache::loadDiplomacyPics()
 void GraphicsCache::loadRoadPics()
 {
   // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
-  int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+  std::string tileset = GameMap::getInstance()->getTileset()->getSubDir();
+  int ts = GameMap::getInstance()->getTileset()->getTileSize();
 
   // load the road pictures
-  SDL_Surface* roadpics = File::getMapsetPicture(tileset, "misc/roads.png");
+  SDL_Surface* roadpics = File::getTilesetPicture(tileset, "misc/roads.png");
 
   // copy alpha values, don't use them
   SDL_SetAlpha(roadpics, 0, 0);
@@ -1909,11 +1924,11 @@ void GraphicsCache::loadRoadPics()
 void GraphicsCache::loadFogPics()
 {
   // GameMap has the actual tileset stored
-  int ts = GameMap::getInstance()->getTileSet()->getTileSize();
-  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
+  int ts = GameMap::getInstance()->getTileset()->getTileSize();
+  std::string tileset = GameMap::getInstance()->getTileset()->getSubDir();
 
   // load the fog pictures
-  SDL_Surface* fogpics = File::getMapsetPicture(tileset, "misc/fog.png");
+  SDL_Surface* fogpics = File::getTilesetPicture(tileset, "misc/fog.png");
 
   // copy alpha values, don't use them
   SDL_SetAlpha(fogpics, 0, 0);
@@ -1944,11 +1959,11 @@ void GraphicsCache::loadFogPics()
 void GraphicsCache::loadBridgePics()
 {
   // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
-  int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+  std::string tileset = GameMap::getInstance()->getTileset()->getSubDir();
+  int ts = GameMap::getInstance()->getTileset()->getTileSize();
 
   // load the bridge pictures
-  SDL_Surface* bridgepics = File::getMapsetPicture(tileset, "misc/bridges.png");
+  SDL_Surface* bridgepics = File::getTilesetPicture(tileset, "misc/bridges.png");
 
   // copy alpha values, don't use them
   SDL_SetAlpha(bridgepics, 0, 0);
@@ -2015,11 +2030,11 @@ void GraphicsCache::loadCityPics()
   SDL_Surface *tmp;
   SDL_PixelFormat *fmt;
   // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
-  int size = GameMap::getInstance()->getTileSet()->getTileSize() * 2;
+  std::string tileset = GameMap::getInstance()->getTileset()->getSubDir();
+  int size = GameMap::getInstance()->getTileset()->getTileSize() * 2;
 
   // load the image for the razed city
-  SDL_Surface* razedpics = File::getMapsetPicture(tileset, "misc/castle_razed.png");
+  SDL_Surface* razedpics = File::getCitysetPicture(tileset, "castle_razed.png");
   // copy alpha values, don't use them
   SDL_SetAlpha(razedpics, 0, 0);
 
@@ -2045,7 +2060,7 @@ void GraphicsCache::loadCityPics()
   SDL_FreeSurface(razedpics);
 
   // load the city pictures
-  SDL_Surface* citypics = File::getMapsetPicture(tileset, "misc/castles.png");
+  SDL_Surface* citypics = File::getCitysetPicture(tileset, "castles.png");
 
   // copy alpha values, don't use them
   SDL_SetAlpha(citypics, 0, 0);
@@ -2085,12 +2100,12 @@ void GraphicsCache::loadTowerPics()
 {
   SDL_Surface *tmp;
   SDL_PixelFormat *fmt;
-  // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
-  int size = GameMap::getInstance()->getTileSet()->getTileSize();
+  // GameMap has the actual cityset stored
+  std::string cityset = GameMap::getInstance()->getCityset()->getSubDir();
+  int size = GameMap::getInstance()->getCityset()->getTileSize();
 
   // load the image for the towers
-  SDL_Surface* towerpics = File::getMapsetPicture(tileset, "misc/towers.png");
+  SDL_Surface* towerpics = File::getCitysetPicture(cityset, "towers.png");
   // copy alpha values, don't use them
   SDL_SetAlpha(towerpics, 0, 0);
 
@@ -2121,12 +2136,12 @@ void GraphicsCache::loadSelectors()
 {
   //load the big selector pictures
   int i;
-  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
+  std::string tileset = GameMap::getInstance()->getTileset()->getSubDir();
 
   // to build flags, we need these three images as basic blocks
-  SDL_Surface* selpics = File::getMapsetPicture(tileset, "misc/selector.png");
+  SDL_Surface* selpics = File::getTilesetPicture(tileset, "misc/selector.png");
   SDL_PixelFormat* fmt = selpics->format;
-  int size = GameMap::getInstance()->getTileSet()->getTileSize();
+  int size = GameMap::getInstance()->getTileset()->getTileSize();
 
   // copy alpha values, don't use them
   SDL_SetAlpha(selpics, 0, 0);
@@ -2154,7 +2169,7 @@ void GraphicsCache::loadSelectors()
   SDL_FreeSurface(selpics);
 
   //load the small selector pictures
-  selpics = File::getMapsetPicture(tileset, "misc/small_selector.png");
+  selpics = File::getTilesetPicture(tileset, "misc/small_selector.png");
   fmt = selpics->format;
   // copy alpha values, don't use them
   SDL_SetAlpha(selpics, 0, 0);
@@ -2186,105 +2201,6 @@ void GraphicsCache::loadSelectors()
   SDL_FreeSurface(selpics);
 }
 
-void GraphicsCache::loadShields()
-{
-  //load the small shieldset
-  unsigned int i;
-  SDL_Rect shieldrect;
-  SDL_Surface* shieldpics = File::getMiscPicture("shieldsetsmall.png");
-  // copy alpha values, don't use them
-  SDL_SetAlpha(shieldpics, 0, 0);
-  SDL_PixelFormat* fmt = shieldpics->format;
-  int size = 8; /*FIXME hardcoded size, should be in .defs? */
-  for (i = 0; i < MAX_PLAYERS + 1; i++)
-    {
-      SDL_Surface* tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, size, size, 
-					      fmt->BitsPerPixel, fmt->Rmask, 
-					      fmt->Gmask, fmt->Bmask, 
-					      fmt->Amask);
-      shieldrect.x = i*size;
-      shieldrect.y = 0;
-      shieldrect.w = shieldrect.h = size;
-      SDL_BlitSurface(shieldpics, &shieldrect, tmp, 0);
-      d_shieldpic[0][i] = SDL_DisplayFormatAlpha(tmp);
-      SDL_FreeSurface(tmp);
-
-      d_shieldmask[0][i]=  SDL_CreateRGBSurface(SDL_SWSURFACE, size, size, 32,
-						0xFF000000, 0xFF0000, 0xFF00, 
-						0xFF);
-      shieldrect.x = i*size;
-      shieldrect.y = size;
-      shieldrect.w = shieldrect.h = size;
-      SDL_BlitSurface(shieldpics, &shieldrect, d_shieldmask[0][i], 0);
-
-    }
-  SDL_FreeSurface(shieldpics);
-  //load the medium shieldset
-  shieldpics = File::getMiscPicture("shieldsetmedium.png");
-  // copy alpha values, don't use them
-  SDL_SetAlpha(shieldpics, 0, 0);
-  fmt = shieldpics->format;
-  int xsize = 11;
-  int ysize = 14;
-  for (i = 0; i < MAX_PLAYERS + 1; i++)
-    {
-      SDL_Surface* tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, xsize, ysize, 
-					      fmt->BitsPerPixel, fmt->Rmask, 
-					      fmt->Gmask, fmt->Bmask, 
-					      fmt->Amask);
-      shieldrect.x = i*xsize;
-      shieldrect.y = 0;
-      shieldrect.w = xsize;
-      shieldrect.h = ysize;
-      SDL_BlitSurface(shieldpics, &shieldrect, tmp, 0);
-      d_shieldpic[1][i] = SDL_DisplayFormatAlpha(tmp);
-      SDL_FreeSurface(tmp);
-
-      d_shieldmask[1][i]=  SDL_CreateRGBSurface(SDL_SWSURFACE, xsize, ysize,
-						32, 0xFF000000, 0xFF0000,
-						0xFF00, 0xFF);
-      shieldrect.x = i*xsize;
-      shieldrect.y = ysize;
-      shieldrect.w = xsize;
-      shieldrect.h = ysize;
-      SDL_BlitSurface(shieldpics, &shieldrect, d_shieldmask[1][i], 0);
-
-    }
-  SDL_FreeSurface(shieldpics);
-  //load the large shieldset
-  shieldpics = File::getMiscPicture("shieldsetlarge.png");
-  // copy alpha values, don't use them
-  SDL_SetAlpha(shieldpics, 0, 0);
-  fmt = shieldpics->format;
-  xsize = 31;
-  ysize = 36;
-  for (i = 0; i < MAX_PLAYERS + 1; i++)
-    {
-      SDL_Surface* tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, xsize, ysize, 
-					      fmt->BitsPerPixel, fmt->Rmask, 
-					      fmt->Gmask, fmt->Bmask, 
-					      fmt->Amask);
-      shieldrect.x = i*xsize;
-      shieldrect.y = 0;
-      shieldrect.w = xsize;
-      shieldrect.h = ysize;
-      SDL_BlitSurface(shieldpics, &shieldrect, tmp, 0);
-      d_shieldpic[2][i] = SDL_DisplayFormatAlpha(tmp);
-      SDL_FreeSurface(tmp);
-
-      d_shieldmask[2][i]=  SDL_CreateRGBSurface(SDL_SWSURFACE, xsize, ysize,
-						32, 0xFF000000, 0xFF0000,
-						0xFF00, 0xFF);
-      shieldrect.x = i*xsize;
-      shieldrect.y = ysize;
-      shieldrect.w = xsize;
-      shieldrect.h = ysize;
-      SDL_BlitSurface(shieldpics, &shieldrect, d_shieldmask[2][i], 0);
-
-    }
-  SDL_FreeSurface(shieldpics);
-}
-
 void GraphicsCache::loadProdShields()
 {
   //load the production shieldset
@@ -2344,17 +2260,17 @@ void GraphicsCache::loadMoveBonusPics()
 void GraphicsCache::loadFlags()
 {
   //GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
+  std::string tileset = GameMap::getInstance()->getTileset()->getSubDir();
 
   // to build flags, we need these three images as basic blocks
-  SDL_Surface* flag = File::getMapsetPicture(tileset, "misc/flags.png");
+  SDL_Surface* flag = File::getTilesetPicture(tileset, "misc/flags.png");
   SDL_PixelFormat* fmt = flag->format;
-  int tilesize = GameMap::getInstance()->getTileSet()->getTileSize();
+  int tilesize = GameMap::getInstance()->getTileset()->getTileSize();
 
   // copy alpha values, don't use them!
   SDL_SetAlpha(flag, 0, 0);
 
-  for (int i = 0; i < 8; i++)
+  for (unsigned int i = 0; i < MAX_STACK_SIZE; i++)
     {
       // first, create the flag image; create a temporary surface...
       SDL_Surface* tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, tilesize, tilesize, 
