@@ -41,6 +41,9 @@ class Location : public ::Object
     void setName(std::string name) {d_name = name;}
 
     Stack *addArmy(Army *a) const;
+    bool isFogged();
+    void deFog();
+    void deFog(Player *p);
 
  protected:
     Stack* getFreeStack(Player *p) const;
