@@ -22,6 +22,7 @@
 #include "hero.h"
 #include "vectoredunitlist.h"
 #include "FogMap.h"
+#include "history.h"
 
 #include "path.h"
 
@@ -29,8 +30,8 @@ using namespace std;
 #define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<flush<<endl;}
 //#define debug(x)
 
-NextTurn::NextTurn(bool turnmode)
-    :d_turnmode(turnmode), d_stop(false)
+NextTurn::NextTurn(bool turnmode, bool random_turns)
+    :d_turnmode(turnmode), d_random_turns (random_turns), d_stop(false)
 {
 }
 
@@ -56,8 +57,16 @@ void NextTurn::start()
         // inform everyone about the next turn 
         snextTurn.emit(plist->getActiveplayer());
         
+	if (plist->getNoOfPlayers() <= 2)
+	{
+          if (plist->checkPlayers() == true) //end of game detected
+	      return;
+	}
+
 	bool break_loop = splayerStart.emit(plist->getActiveplayer());
 
+	if (break_loop)
+	  return;
         //Let the player do his duties...
         plist->getActiveplayer()->startTurn();
 
@@ -71,11 +80,12 @@ void NextTurn::start()
         plist->nextPlayer();
         
         //if it is the first player's turn now, a new round has started
-        if (plist->getActiveplayer() == plist->getFirstLiving())
+        if (Playerlist::getInstance()->getActiveplayer() == 
+	    Playerlist::getInstance()->getFirstLiving())
         {
-          if (Playerlist::getInstance()->checkPlayers() == true)
+          if (plist->checkPlayers() == true)
 	    {
-	      if (d_stop)
+	      if (plist->getNoOfPlayers() <= 1)
 		break;
 	      if (plist->getActiveplayer()->isDead())
 		plist->nextPlayer();
@@ -83,6 +93,7 @@ void NextTurn::start()
 	  finishRound();
 	  snextRound.emit();
 	}
+	  
     }
 }
 
@@ -99,7 +110,7 @@ void NextTurn::endTurn()
       snextRound.emit();
     }
 
-  start();
+    start();
 }
 
 void NextTurn::startTurn()
@@ -141,6 +152,7 @@ void NextTurn::finishTurn()
 
 void NextTurn::finishRound()
 {
+  Playerlist *plist = Playerlist::getInstance();
   //Put everything that has to be done when a new round starts in here.
   //E.g. increase the round number in GameScenario. (this is done with
   //the snextRound signal, but useful for an example).
@@ -148,23 +160,21 @@ void NextTurn::finishRound()
   if (!d_turnmode)
     {
       //do this for all players at once
-      Playerlist::iterator pit = Playerlist::getInstance()->begin();
-      for (; pit != Playerlist::getInstance()->end(); pit++)
+      
+      for (Playerlist::iterator it = plist->begin(); it != plist->end(); it++)
 	{
-	  if ((*pit)->isDead())
+	  if ((*it)->isDead())
 	    continue;
 
 	  //produce armies
-	  Citylist::getInstance()->nextTurn(*pit);
+	  Citylist::getInstance()->nextTurn(*it);
 
 	  //heal armies
-	  (*pit)->getStacklist()->nextTurn();
+	  (*it)->getStacklist()->nextTurn();
 
 	}
     }
 
-  Playerlist::getInstance()->calculateWinners();
-
   // heal the stacks in the ruins
   Ruinlist* rl = Ruinlist::getInstance();
   for (Ruinlist::iterator it = rl->begin(); it != rl->end(); it++)
@@ -173,4 +183,8 @@ void NextTurn::finishRound()
       if (keeper)
 	keeper->nextTurn();
     }
+    
+  if (d_random_turns)
+    plist->randomizeOrder();
+
 }
