@@ -61,10 +61,10 @@ class QuestCitySack : public Quest, public sigc::trackable
          //! Returns the city to be sacked
          City* getCity() const;
 
+	 void armyDied(Army *a, bool heroIsCulprit);
+	 void cityAction(City *c, CityDefeatedAction action, 
+			       bool heroIsCulprit, int gold);
     private:
-         /** slot that would receive the scitySacked (signal) */
-         void citySacked (City* city, Stack* s, int gold, std::list<Uint32> sacked_types);
-         void cityRazed (City* city, Stack* s);
 
          /** \brief Make quest description from the city we'll sack */
          void initDescription();
