@@ -28,13 +28,19 @@ using namespace std;
 Quest::Quest(QuestsManager& q_mgr, Uint32 hero, Type type)
     :d_q_mgr(q_mgr), d_hero(hero), d_type(type), d_pending(false)
 {
+  Hero *h = getHeroById(hero);
+  d_player_id = h->getPlayer()->getId();
+  d_hero_name = h->getName();
 }
 
 Quest::Quest(QuestsManager& q_mgr, XML_Helper* helper)
-    :d_q_mgr(q_mgr), d_pending(false)
+    :d_q_mgr(q_mgr)
 {
     helper->getData(d_type, "type");
     helper->getData(d_hero, "hero");
+    helper->getData(d_hero_name, "hero_name");
+    helper->getData(d_pending, "pending_deletion");
+    helper->getData(d_player_id, "player");
 }
 
 Hero* Quest::getHeroById(Uint32 hero, Stack** stack)
@@ -67,6 +73,9 @@ bool Quest::save(XML_Helper* helper) const
 
     retval &= helper->saveData("type", d_type);
     retval &= helper->saveData("hero", d_hero);
+    retval &= helper->saveData("hero_name", d_hero_name);
+    retval &= helper->saveData("pending_deletion", d_pending);
+    retval &= helper->saveData("player", d_player_id);
 
     return retval;
 }
