@@ -21,6 +21,8 @@
 #include "xmlhelper.h"
 #include "defs.h"
 
+#include "tilestyleset.h"
+
 /** Class which describes the terrain
   * 
   * Many tiles are put together to form a tileset. Thus, a tile describes a
@@ -28,7 +30,7 @@
   * etc.) as well as the images together.
   */
 
-class Tile
+class Tile : public std::vector<TileStyleSet*>
 {
     public:
         //! Describe terrain types
@@ -42,49 +44,48 @@ class Tile
 
         ~Tile();
 
-        //! Set the images of the terrain. See MapRenderer how they are used.
-        void setSurface(int t, SDL_Surface* surface){d_surface[t] = surface;}
-
-        //! Prints some debug information
-        void printDebugInfo() const;
-
-        
-        //! Get a surface . See MapRenderer how they are used.
-        SDL_Surface* getSurface(int t) const {return d_surface[t];}
-
-        //! Get the name of the terrain
-        std::string getName() const {return __(d_name);}
-
         //! Get the number of movement points needed to cross this tile
         Uint32 getMoves() const {return d_moves;}
 
         //! Get the color associated with this tile for the smallmap
         SDL_Color getColor() const {return d_color;}
+        //! Set the color associated with this tile for the smallmap
+	void setColor(SDL_Color clr) {d_color = clr;}
 
         //! Get the type (grass, hill,...) of this tile type
         Type getType() const {return d_type;}
                 
         //! Get the pattern (solid, stippled, random) of this type
         Pattern getPattern() const {return d_pattern;}
+        //! set the pattern (solid, stippled, random) of this type
+	void setPattern(Pattern pattern) {d_pattern = pattern;}
+
+	std::string getName() const {return d_name;}
 
         //! Get the alternate color associated with this tile's pattern 
 	//!This "second" colour gets stippled, or randomized, or sunken
         SDL_Color getSecondColor() const {return d_second_color;}
+        //! set the alternate color associated with this tile's pattern 
+        void setSecondColor(SDL_Color color) {d_second_color = color;}
 
         //! Get another alternate color associated with this tile's pattern 
 	//!This "third" colour gets randomized, or sunken
         SDL_Color getThirdColor() const {return d_third_color;}
+        //! set another alternate color associated with this tile's pattern 
+        void setThirdColor(SDL_Color color) {d_third_color = color;}
+
+	void instantiatePixmaps(std::string tileset, Uint32 tilesize);
 
     private:
         // DATA
-        SDL_Surface* d_surface[8*4];      // base tiles * 4 = corners
-        std::string d_name;                // name    
+	std::string d_name;
         Uint32 d_moves;                    // moves needed to walk over maptile
         SDL_Color d_color;                // color shown in the smallmap
         Type d_type;
 	Pattern d_pattern;
         SDL_Color d_second_color;         // the extra pattern-related color
         SDL_Color d_third_color;         // another pattern-related color
+
 };
 
 #endif // TILE_H
