@@ -28,8 +28,8 @@
 #define debug(x) {std::cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 //#define debug(x)
 
-AI_Dummy::AI_Dummy(std::string name, Uint32 armyset, SDL_Color color, int player_no)
-    :RealPlayer(name, armyset, color, Player::AI_DUMMY, player_no)
+AI_Dummy::AI_Dummy(std::string name, Uint32 armyset, SDL_Color color, int width, int height, int player_no)
+    :RealPlayer(name, armyset, color, width, height, Player::AI_DUMMY, player_no)
 {
 }
 
@@ -70,10 +70,6 @@ bool AI_Dummy::invadeCity(City* c)
 
 bool AI_Dummy::recruitHero(Hero* hero, City *city, int cost)
 {
-    History_HeroEmerges *item = new History_HeroEmerges();
-    item->fillData(hero, city);
-    d_history.push_back(item);
-
     return false;   //never recruit a hero
 }
 
