@@ -24,6 +24,7 @@
 #include "path.h"
 #include "AI_Analysis.h"
 #include "AI_Allocation.h"
+#include "AI_Diplomacy.h"
 #include "action.h"
 #include "xmlhelper.h"
 #include "history.h"
@@ -33,8 +34,8 @@ using namespace std;
 #define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<flush<<endl;}
 //#define debug(x)
 
-AI_Smart::AI_Smart(string name, unsigned int armyset, SDL_Color color, int player_no)
-  :RealPlayer(name, armyset, color, Player::AI_SMART, player_no),
+AI_Smart::AI_Smart(string name, unsigned int armyset, SDL_Color color, int width, int height, int player_no)
+  :RealPlayer(name, armyset, color, width, height, Player::AI_SMART, player_no),
    d_mustmakemoney(0)
 {
 }
@@ -84,6 +85,10 @@ bool AI_Smart::startTurn()
             break;
     }
     d_stacklist->setActivestack(0);
+
+    AI_Diplomacy *diplomacy = new AI_Diplomacy (this);
+    diplomacy->makeProposals();
+    delete diplomacy;
     return true;
 }
 
@@ -103,10 +108,6 @@ bool AI_Smart::invadeCity(City* c)
 bool AI_Smart::recruitHero(Hero* hero, City *city, int cost)
 {
     debug("AI_Smart: hero recruited")
-    History_HeroEmerges *item = new History_HeroEmerges();
-    item->fillData(hero, city);
-    d_history.push_back(item);
-
     return true;    //always recruit heroes
 }
 
