@@ -22,6 +22,7 @@
 
 #include "xmlhelper.h"
 #include "army.h"
+#include "armyset.h"
 
 
 /** List of all available armysets
@@ -39,23 +40,28 @@
   * Since several classes access this class, it is implemented as a singleton.
   */
 
-class Armysetlist : public sigc::trackable
+class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 {
     public:
         //! return the singleton instance of this class
         static Armysetlist* getInstance();
 
-        //! Explicitely delete the singleton instance of this class
+        //! Explicitly delete the singleton instance of this class
         static void deleteInstance();
 
-
         /** Returns an army prototype
           *
           * @param id       the id of the armyset
           * @param index    the index of the army within the set
           * @return the requested army or 0 on error
           */
-        const Army* getArmy(Uint32 id, Uint32 index) const;
+        Army* getArmy(Uint32 id, Uint32 index) const;
+
+	SDL_Surface * getShipPic (Uint32 id);
+	SDL_Surface * getShipMask (Uint32 id);
+	SDL_Surface * getStandardPic (Uint32 id);
+	SDL_Surface * getStandardMask (Uint32 id);
+        Uint32 getTileSize(Uint32 id);
 
         /** Returns the size of a specific armyset
           * 
@@ -72,14 +78,25 @@ class Armysetlist : public sigc::trackable
           */
         std::string getName(Uint32 id) const;
 
+        //! Returns the names of all armysets
+	std::list<std::string> getNames();
+
+        /** Returns the Id of a specific armyset by name
+          * 
+          * @param armyset       the name of the armyset
+          * @return the id of the armyset (0 on error)
+          */
+	Uint32 getArmysetId(std::string armyset) {return d_ids[armyset];}
+
         /** Returns a list of all existing army sets
           */
         std::vector<Uint32> getArmysets() const;
 
-	// FIXME: quick hack
-        typedef std::map<std::string, Uint32> FileNameMap;
-	FileNameMap file_names;
-	
+	/* Reads in the pixmap and mask for every army of every armyset.
+	 * This can only be done after SDL is initialized.
+	 */
+	void instantiatePixmaps();
+
     private:
         //! Constructor; loads all armysets it can find
         Armysetlist();
@@ -87,26 +104,19 @@ class Armysetlist : public sigc::trackable
         //! Destructor; mainly clears the lists
         ~Armysetlist();
 
+        //! Callback for loading. See XML_Helper for details.
+	bool load(std::string tag, XML_Helper *helper);
 
         //! Loads a specific armyset
         bool loadArmyset (std::string name);
         
-        //! Callback function for the armyset tag (see XML_Helper)
-        bool loadGlobalStuff(std::string tag, XML_Helper* helper);
-
-        //! Callback function for the army tag (see XML_Helper)
-        bool loadArmy(std::string tag, XML_Helper* helper);
-
-        
         typedef std::map<Uint32, std::vector<Army*> > ArmyMap;
         typedef std::map<Uint32, std::string> NameMap;
+        typedef std::map<std::string, Uint32> IdMap;
         
         ArmyMap d_armies;
         NameMap d_names;
-
-        // temporary variables for game loading
-        Uint32 d_loading;
-        std::string d_file;
+        IdMap d_ids;
 
         static Armysetlist* s_instance;
 };
