@@ -113,7 +113,8 @@ class City : public Location
         void conquer(Player* newowner);
         
         //! Sets the production to random starting values
-        void setRandomArmytypes(bool produce_allies);
+	//! @param likely = 0, 1, 2, 3.  3 is more armies, more powerful.
+	void setRandomArmytypes(bool produce_allies, int likely);
 
         //! Produces the strongest army the city can produce
         void produceStrongestArmy();
@@ -190,6 +191,13 @@ class City : public Location
 	//! Returns true if the city isn't accepting too many vectored armies
 	bool canAcceptVectoredUnit();
 
+	//! Returns true if the city can accept a number of vectored armies 
+	bool canAcceptVectoredUnits(Uint32 number_of_units);
+
+	//! sets the point where the city will send the produced armies to.
+	//Also changes the vectored units that are "en route" from this city.
+	bool changeVectorDestination(Vector<int> dest);
+
     private:
 
         //! Produces the currently selected army
@@ -197,6 +205,10 @@ class City : public Location
 
 	void randomlyImproveOrDegradeArmy(Army *army);
 
+	//! sort the armies that this city produces by strength
+	//! Note: only use this prior to the start of game.
+	void sortProduction();
+
         // DATA
         Player* d_player;           // Owner
         
