@@ -75,6 +75,9 @@ class Citylist : public ObjectList<City>, public sigc::trackable
         //! Returns the city closest to pos but within N tiles
         City* getNearestCity(const Vector<int>& pos, int dist);
 
+	//! Returns the next city nearest to City
+	City* getNearestCity(City *city);
+
         //! Returns the city closest to pos
         City* getNearestCity(const Vector<int>& pos);
 
@@ -112,6 +115,15 @@ class Citylist : public ObjectList<City>, public sigc::trackable
 	//! find the center point for all of the given player's cities
 	Vector<int> calculateCenterOfTerritory (Player *p);
 
+	//! are any other cities vectoring to here?
+	bool isVectoringTarget(City *target);
+
+	//! get the set of cities vectoring to here.
+	std::list<City*> getCitiesVectoringTo(City *target);
+
+	//! get the nearest city to POS, but is farther than DIST tiles
+	City* getNearestCityPast(const Vector<int>& pos, int dist);
+
     protected:
         // CREATORS
         Citylist();
