@@ -20,8 +20,8 @@
 
 #include <libintl.h>
 
-#define LORDSAWAR_SAVEGAME_VERSION "0.0.7"
-#define LORDSAWAR_CONFIG_VERSION "0.0.7"
+#define LORDSAWAR_SAVEGAME_VERSION "0.0.8"
+#define LORDSAWAR_CONFIG_VERSION "0.0.8"
 #define ENABLE_NLS 1 // Very important toactivate localization
 #define _(string) gettext(string) // Macro for the gettext
 #define __(astring) std::string(gettext(astring.c_str()))
@@ -42,7 +42,6 @@ const unsigned int ROAD_TYPES=12;
 const unsigned int FOG_TYPES=13; 
 const unsigned int BRIDGE_TYPES=4; 
 const unsigned int CURSOR_TYPES=12; 
-const unsigned int SIGNPOSTS_RATIO=6; // #:1 dynamic vs static signposts
 const unsigned int MAX_ARMIES_VECTORED_TO_ONE_CITY = 4;
 const unsigned int MAX_TURNS_FOR_VECTORING = 2;
 const unsigned int MAX_BOAT_MOVES = 18;
@@ -50,6 +49,7 @@ const unsigned int CUSP_OF_WAR_ROUND = 9;
 const unsigned int DIPLOMACY_STARTING_SCORE = 8;
 const unsigned int DIPLOMACY_MAX_SCORE = 15;
 const unsigned int DIPLOMACY_MIN_SCORE = 0;
+const unsigned int MAX_STACK_SIZE = 8;
 
 // from www.boost.org - derivation from this class makes the derived class
 // noncopyable
