@@ -146,7 +146,7 @@ void EditorBigMap::mouse_motion_event(MouseMotionEvent e)
 	
 	// FIXME: show a drag cursor
 	
-	int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+	int ts = GameMap::getInstance()->getTileset()->getTileSize();
 	SDL_Surface *screen = SDL_GetVideoSurface();
 	Vector<int> screen_dim(screen->w, screen->h);
 	view_pos = clip(Vector<int>(0, 0),
@@ -217,7 +217,7 @@ void EditorBigMap::after_draw()
     std::vector<Vector<int> > tiles = get_cursor_tiles();
 
     // draw each tile
-    int tilesize = GameMap::getInstance()->getTileSet()->getTileSize();
+    int tilesize = GameMap::getInstance()->getTileset()->getTileSize();
     for (std::vector<Vector<int> >::iterator i = tiles.begin(),
 	     end = tiles.end(); i != end; ++i)
     {
@@ -274,12 +274,12 @@ void EditorBigMap::after_draw()
 	    break;
 	    
 	case SIGNPOST:
-	    pic = d_signpostpic;
+	    pic = GraphicsCache::getInstance()->getSignpostPic();
 	    SDL_BlitSurface(pic, 0, buffer, &r);
 	    break;
 	    
 	case ROAD:
-	    pic = GraphicsCache::getInstance()->getRoadPic(tile_to_road_type(*i));
+	    pic = GraphicsCache::getInstance()->getRoadPic(Roadlist::getInstance()->calculateType(*i));
 	    SDL_BlitSurface(pic, 0, buffer, &r);
 	    break;
 	case PORT:
@@ -340,61 +340,6 @@ int EditorBigMap::tile_to_bridge_type(Vector<int> t)
 }
 
 
-int EditorBigMap::tile_to_road_type(Vector<int> t)
-{
-    // examine neighbour tiles to discover whether there's a road on them
-    bool u = false; //up
-    bool b = false; //bottom
-    bool l = false; //left
-    bool r = false; //right
-
-    if (t.y > 0)
-      u = Roadlist::getInstance()->getObjectAt(t + Vector<int>(0, -1));
-    if (t.y < GameMap::getHeight() - 1)
-      b = Roadlist::getInstance()->getObjectAt(t + Vector<int>(0, 1));
-    if (t.x > 0)
-      l = Roadlist::getInstance()->getObjectAt(t + Vector<int>(-1, 0));
-    if (t.x < GameMap::getWidth() - 1)
-    r = Roadlist::getInstance()->getObjectAt(t + Vector<int>(1, 0));
-
-    // then translate this to the type
-    int type = 2; 
-    //show road type 2 when no other road tiles are around
-    if (!u && !b && !l && !r)
-	type = 2;
-    else if (u && b && l && r)
-	type = 2;
-    else if (!u && b && l && r)
-	type = 9;
-    else if (u && !b && l && r)
-	type = 8;
-    else if (u && b && !l && r)
-	type = 7;
-    else if (u && b && l && !r)
-	type = 10;
-    else if (u && b && !l && !r)
-	type = 1;
-    else if (!u && !b && l && r)
-	type = 0;
-    else if (u && !b && l && !r)
-	type = 3;
-    else if (u && !b && !l && r)
-	type = 4;
-    else if (!u && b && l && !r)
-	type = 6;
-    else if (!u && b && !l && r)
-	type = 5;
-    else if (u && !b && !l && !r)
-	type = 1;
-    else if (!u && b && !l && !r)
-	type = 1;
-    else if (!u && !b && l && !r)
-	type = 0;
-    else if (!u && !b && !l && r)
-	type = 0;
-    return type;
-}
-
 
 namespace
 {
@@ -421,7 +366,7 @@ namespace
 void EditorBigMap::change_map_under_cursor()
 {
     std::vector<Vector<int> > tiles = get_cursor_tiles();
-    TileSet* ts = GameMap::getInstance()->getTileSet();
+    Tileset* ts = GameMap::getInstance()->getTileset();
     
     // find the index of the "grass" tile
     unsigned int grass_index;
@@ -465,7 +410,7 @@ void EditorBigMap::change_map_under_cursor()
 	      }
 	    else
 	      {
-		TileSet *tileset = GameMap::getInstance()->getTileSet();
+		Tileset *tileset = GameMap::getInstance()->getTileset();
 		TileStyle *tile_style;
 		tile_style = tileset->getTileStyle(pointer_tile_style_id);
 		maptile->setTileStyle (tile_style);
@@ -649,7 +594,8 @@ void EditorBigMap::change_map_under_cursor()
 	    
 	case PORT:
 	    if (maptile->getBuilding() == Maptile::NONE 
-		&& maptile->getMaptileType() != Tile::WATER)
+		&& maptile->getMaptileType() == Tile::WATER &&
+		maptile->getTileStyle()->getType() != TileStyle::INNERMIDDLECENTER)
 	    {
 		maptile->setBuilding(Maptile::PORT);
 		Portlist::getInstance()->push_back(Port(tile));
@@ -678,7 +624,7 @@ void EditorBigMap::change_map_under_cursor()
 		 || maptile->getBuilding() == Maptile::ROAD)
 		&& maptile->getMaptileType() != Tile::WATER)
 	    {
-		int type = tile_to_road_type(tile);
+		int type = Roadlist::getInstance()->calculateType(tile);
 		if (maptile->getBuilding() == Maptile::NONE)
 		{
 		    maptile->setBuilding(Maptile::ROAD);
@@ -696,7 +642,7 @@ void EditorBigMap::change_map_under_cursor()
 			Vector<int> pos(x, y);
 			if (Road *r = Roadlist::getInstance()->getObjectAt(pos))
 			{
-			    int newtype = tile_to_road_type(pos);
+			    int newtype = Roadlist::getInstance()->calculateType(pos);
 			    r->setType(newtype);
 			}
 		    }
