@@ -26,6 +26,8 @@
 #include "../File.h"
 #include "../tileset.h"
 #include "../tilesetlist.h"
+#include "../citysetlist.h"
+#include "../shieldsetlist.h"
 #include "../GameMap.h"
 
 
@@ -54,19 +56,65 @@ NewMapDialog::NewMapDialog()
     xml->get_widget("signposts_scale", signposts_scale);
     // fill in tile themes combobox
     tile_theme_combobox = manage(new Gtk::ComboBoxText);
+    shield_theme_combobox = manage(new Gtk::ComboBoxText);
+    city_theme_combobox = manage(new Gtk::ComboBoxText);
     
+    Uint32 counter = 0;
+    Uint32 default_id = 0;
     Tilesetlist *tl = Tilesetlist::getInstance();
     std::list<std::string> tile_themes = tl->getNames();
     for (std::list<std::string>::iterator i = tile_themes.begin(),
 	     end = tile_themes.end(); i != end; ++i)
+      {
+	if (*i == "Default")
+	  default_id = counter;
 	tile_theme_combobox->append_text(Glib::filename_to_utf8(*i));
+	counter++;
+      }
 
-    tile_theme_combobox->set_active(0);
+    tile_theme_combobox->set_active(default_id);
 
     Gtk::Box *tile_set_box;
     xml->get_widget("tile_set_box", tile_set_box);
     tile_set_box->pack_start(*tile_theme_combobox, Gtk::PACK_SHRINK);
 
+    counter = 0;
+    default_id = 0;
+    Shieldsetlist *sl = Shieldsetlist::getInstance();
+    std::list<std::string> shield_themes = sl->getNames();
+    for (std::list<std::string>::iterator i = shield_themes.begin(),
+	     end = shield_themes.end(); i != end; ++i)
+      {
+	if (*i == "Default")
+	  default_id = counter;
+	shield_theme_combobox->append_text(Glib::filename_to_utf8(*i));
+	counter++;
+      }
+
+    shield_theme_combobox->set_active(default_id);
+
+    Gtk::Box *shield_set_box;
+    xml->get_widget("shield_set_box", shield_set_box);
+    shield_set_box->pack_start(*shield_theme_combobox, Gtk::PACK_SHRINK);
+
+    counter = 0;
+    default_id = 0;
+    Citysetlist *cl = Citysetlist::getInstance();
+    std::list<std::string> city_themes = cl->getNames();
+    for (std::list<std::string>::iterator i = city_themes.begin(),
+	     end = city_themes.end(); i != end; ++i)
+      {
+	if (*i == "Default")
+	  default_id = counter;
+	city_theme_combobox->append_text(Glib::filename_to_utf8(*i));
+	counter++;
+      }
+
+    city_theme_combobox->set_active(default_id);
+
+    Gtk::Box *city_set_box;
+    xml->get_widget("city_set_box", city_set_box);
+    city_set_box->pack_start(*city_theme_combobox, Gtk::PACK_SHRINK);
 
     // create fill style combobox
     fill_style_combobox = manage(new Gtk::ComboBoxText);
@@ -136,6 +184,12 @@ void NewMapDialog::run()
 	map.tileset = Tilesetlist::getInstance()->getTilesetDir
 	  (Glib::filename_from_utf8(tile_theme_combobox->get_active_text()));
 
+	map.shieldset = Shieldsetlist::getInstance()->getShieldsetDir
+	  (Glib::filename_from_utf8(shield_theme_combobox->get_active_text()));
+
+	map.cityset = Citysetlist::getInstance()->getCitysetDir
+	  (Glib::filename_from_utf8(city_theme_combobox->get_active_text()));
+
 	if (map.fill_style == -1)
 	{
 	    map.grass = int(grass_scale->get_value());
@@ -190,7 +244,7 @@ void NewMapDialog::on_map_size_changed()
 
 void NewMapDialog::add_fill_style(Tile::Type tile_type)
 {
-    TileSet *tileset = GameMap::getInstance()->getTileSet();
+    Tileset *tileset = GameMap::getInstance()->getTileset();
     Tile *tile = (*tileset)[tileset->getIndex(tile_type)];
     fill_style_combobox->append_text(tile->getName());
     fill_style.push_back(tile_type);
