@@ -26,6 +26,7 @@ struct GameParameters
 
 	Type type;
 	std::string name;
+	int id;
     };
 
     std::vector<Player> players;
@@ -34,7 +35,7 @@ struct GameParameters
     {
 	int width, height;
 	int grass, water, swamp, forest, hills, mountains;
-	int cities, ruins, temples;
+	int cities, ruins;
     };
 
     Map map;
@@ -43,6 +44,8 @@ struct GameParameters
     std::string map_path;
     std::string tile_theme;
     std::string army_theme;
+    std::string shield_theme;
+    std::string city_theme;
 
     enum ProcessArmies {
 	PROCESS_ARMIES_AT_PLAYERS_TURN = 0,
@@ -71,6 +74,7 @@ struct GameParameters
     bool military_advisor;
     bool random_turns;
     bool cities_can_produce_allies;
+    int difficulty;
 };
 
 #endif
