@@ -28,6 +28,7 @@
 #include "army.h"
 #include "fight.h"
 #include "game-parameters.h"
+#include "player.h"
 
 class NextTurn;
 class GameBigMap;
@@ -66,9 +67,18 @@ class Game
     void park_selected_stack();
     void deselect_selected_stack();
     void search_selected_stack();
-    void move_selected_stack();
+    void move_selected_stack_along_path();
+    void move_selected_stack_northwest();
+    void move_selected_stack_north();
+    void move_selected_stack_northeast();
+    void move_selected_stack_east();
+    void move_selected_stack_west();
+    void move_selected_stack_southwest();
+    void move_selected_stack_south();
+    void move_selected_stack_southeast();
     void move_all_stacks();
     void end_turn();
+    void recalculate_moves_for_stack(Stack *s);
 
     void startGame(); // initiate game flow
     void loadGame();
@@ -76,6 +86,7 @@ class Game
     // save current game, returns true if successful
     bool saveGame(std::string file);
 
+    GameScenario *getScenario() {return d_gameScenario;};
     GameBigMap &get_bigmap();
     SmallMap &get_smallmap();
     
@@ -92,23 +103,28 @@ class Game
 	can_search_selected_stack,
 	can_inspect_selected_stack,
 	can_plant_standard_selected_stack,
+	can_move_selected_stack_along_path,
 	can_move_selected_stack,
 	can_group_ungroup_selected_stack,
 	can_move_all_stacks,
 	can_disband_stack,
 	can_change_signpost,
 	can_see_history,
+	received_diplomatic_proposal,
 	can_end_turn;
     sigc::signal<void, Stack *> stack_info_changed;
     sigc::signal<void, Glib::ustring, MapTipPosition> map_tip_changed;
     sigc::signal<void, Stack *, MapTipPosition> stack_tip_changed;
     sigc::signal<void, Ruin*, Stack*, Reward*> ruin_searched;
     sigc::signal<void, Ruin*, Stack*> sage_visited;
-    sigc::signal<void, Fight &> fight_started;
+    sigc::signal<void, Fight &, bool> fight_started;
     sigc::signal<void, Stack *, Stack *> ruinfight_started;
     sigc::signal<void, float> advice_asked;
     sigc::signal<void, Fight::Result> ruinfight_finished;
     sigc::signal<bool, Player *, Hero *, City *, int> hero_offers_service;
+    sigc::signal<bool, int > enemy_offers_surrender;
+    sigc::signal<void, bool> surrender_answered;
+    sigc::signal<bool, Player *, Stack *, Player *, Vector<int> > stack_considers_treachery;
     sigc::signal<bool, bool, Temple *, int> temple_searched;
     sigc::signal<void, Hero *, Quest *> quest_assigned;
     sigc::signal<CityDefeatedAction, City *, int> city_defeated;
@@ -136,6 +152,9 @@ class Game
     */
     int loadHeroTemplates();
 
+    // move the selected stack one tile in a given direction
+    void move_selected_stack_dir(int diffx, int diffy);
+
     // centers the map on a city of the active player
     void center_view_on_city();
 
@@ -151,6 +170,9 @@ class Game
     //! Possibly recruit a new hero at the beginning of a turn
     void maybeRecruitHero(Player *p);
 
+    //! Maybe peform treachery
+    bool maybeTreachery(Stack *stack, Player *them, Vector<int> pos);
+
     // bigmap callbacks
     void on_stack_selected(Stack* s);
     void on_city_queried (City* c, bool brief);
@@ -177,6 +199,11 @@ class Game
     void stackDied(Stack* s);
     //! Called whenever players fight
     void on_fight_started(Fight &fight);
+    //! Called whenever a player receives an offer of surrender
+    void on_surrender_offered(Player *recipient);
+    void nextRound();
+    //! Called after a player's stack attacks a city
+    void on_city_fight_finished(City *city, Fight::Result result);
 
 
     
