@@ -29,6 +29,7 @@
 #include "signpostlist.h"
 #include "templelist.h"
 #include "roadlist.h"
+#include "bridgelist.h"
 #include "ruin.h"
 #include "signpost.h"
 #include "temple.h"
@@ -60,6 +61,7 @@ GameBigMap::GameBigMap(bool intense_combat, bool see_opponents_production,
   d_see_opponents_production = see_opponents_production;
   d_see_opponents_stacks = see_opponents_stacks;
   d_military_advisor = military_advisor;
+  d_fighting = false;
 
   current_tile.x = current_tile.y = 0;
   mouse_state = NONE;
@@ -415,7 +417,9 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 		    d_cursor = GraphicsCache::HAND;
 		  else
 		    {
-		      if (t->getMaptileType() == Tile::WATER)
+		      Bridgelist *bl = Bridgelist::getInstance();
+		      if (t->getMaptileType() == Tile::WATER &&
+			  bl->getObjectAt(tile) == NULL)
 			d_cursor = GraphicsCache::SHIP;
 		      else
 			d_cursor = GraphicsCache::FEET;
@@ -506,7 +510,7 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
       if (mouse_state == NONE && length(delta) <= 2)
 	return;
 
-      int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+      int ts = GameMap::getInstance()->getTileset()->getTileSize();
       SDL_Surface *screen = SDL_GetVideoSurface();
       Vector<int> screen_dim(screen->w, screen->h);
       view_pos = clip(Vector<int>(0, 0),
@@ -547,7 +551,7 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 void GameBigMap::after_draw()
 {
   GraphicsCache *gc = GraphicsCache::getInstance();
-  int tilesize = GameMap::getInstance()->getTileSet()->getTileSize();
+  int tilesize = GameMap::getInstance()->getTileset()->getTileSize();
 
   Stack* stack = Playerlist::getActiveplayer()->getActivestack();
 
@@ -621,11 +625,21 @@ void GameBigMap::after_draw()
 	    }
 
 	  draw_stack (stack);
-	  if (num_selected > 1)
-	    tmp = gc->getSelectorPic(0, bigframe, stack->getPlayer());
+
+	  if (d_fighting)
+	    {
+	      tmp = gc->getExplosionPic();
+	      SDL_BlitSurface(tmp, 0, buffer, &r);
+	    }
 	  else
-	    tmp = gc->getSelectorPic(1, smallframe, stack->getPlayer());
-	  SDL_BlitSurface(tmp, 0, buffer, &r);
+	    {
+	      if (num_selected > 1)
+		tmp = gc->getSelectorPic(0, bigframe, stack->getPlayer());
+	      else
+		tmp = gc->getSelectorPic(1, smallframe, stack->getPlayer());
+	      SDL_BlitSurface(tmp, 0, buffer, &r);
+	    }
+
 	}
     }
 }
