@@ -24,6 +24,7 @@
 #include "game-window.h"
 #include "../defs.h"
 #include "../GraphicsCache.h"
+#include "../GameScenario.h"
 Driver::Driver()
 {
     splash_window.reset(new SplashWindow);
@@ -54,7 +55,6 @@ Driver::Driver()
 	g.map.mountains = 5;
 	g.map.cities = 20;
 	g.map.ruins = 25;
-	g.map.temples = 25;
 	g.map_path = "";
 	g.play_with_quests = false;
 	g.hidden_map = false;
@@ -69,6 +69,7 @@ Driver::Driver()
 	g.army_theme = "Default";
 	g.process_armies = GameParameters::PROCESS_ARMIES_AT_PLAYERS_TURN;
 	
+	g.difficulty = GameScenario::calculate_difficulty_rating(g);
 	on_new_game_requested(g);
     }
     else
