@@ -94,7 +94,6 @@ void FightOrderDialog::addArmyType(Uint32 army_type)
     const Army *a = alist->getArmy(player->getArmyset(), army_type);
     (*i)[armies_columns.name] = a->getName();
     (*i)[armies_columns.image] = to_pixbuf(gc->getArmyPic(player->getArmyset(),
-                                           army_type,
-                                           player, 1, NULL));
+                                           army_type, player, NULL));
     (*i)[armies_columns.army_type] = a->getType();
 }
