@@ -34,7 +34,7 @@ class Army;
 class FightWindow: public sigc::trackable
 {
  public:
-    FightWindow(Fight &fight);
+    FightWindow(Fight &fight, bool intense_combat);
     ~FightWindow();
 
     void set_parent_window(Gtk::Window &parent);
@@ -52,6 +52,7 @@ class FightWindow: public sigc::trackable
 	Army *army;
 	int hp;
 	Gtk::ProgressBar *bar;
+	Gtk::Image *image;
     };
     
     typedef std::vector<ArmyItem> army_items_type;
@@ -80,6 +81,7 @@ class FightWindow: public sigc::trackable
 
     bool do_round();
     bool d_quick;
+    bool d_intense_combat;
 };
 
 #endif
