@@ -30,7 +30,9 @@
 #include <gtkmm/scale.h>
 
 #include "../game-parameters.h"
+#include "game-options-dialog.h"
 
+class XML_Helper;
 
 // dialog for choosing parameters for starting a new game
 class GamePreferencesDialog
@@ -51,7 +53,9 @@ class GamePreferencesDialog
     Gtk::Button *start_game_button;
     Gtk::ComboBoxText *tile_theme_combobox;
     Gtk::ComboBoxText *army_theme_combobox;
-    Gtk::ComboBox *process_armies_combobox;
+    Gtk::ComboBoxText *shield_theme_combobox;
+    Gtk::ComboBoxText *city_theme_combobox;
+    Gtk::Label *difficulty_label;
     Gtk::RadioButton *random_map_radio;
     Gtk::FileChooserButton *load_map_filechooser;
     Gtk::Widget *random_map_container;
@@ -70,13 +74,11 @@ class GamePreferencesDialog
     Gtk::ToggleButton *mountains_random_togglebutton;
     Gtk::Scale *cities_scale;
     Gtk::ToggleButton *cities_random_togglebutton;
-    Gtk::Scale *ruins_scale;
-    Gtk::ToggleButton *ruins_random_togglebutton;
-    Gtk::Scale *temples_scale;
-    Gtk::ToggleButton *temples_random_togglebutton;
     Gtk::CheckButton *cities_can_produce_allies_checkbutton;
+    Gtk::ComboBox *difficulty_combobox;
 
     enum { MAP_SIZE_NORMAL = 0, MAP_SIZE_SMALL, MAP_SIZE_TINY };
+    enum { BEGINNER = 0, INTERMEDIATE, ADVANCED, I_AM_THE_GREATEST, CUSTOM};
 
     Gtk::VBox *players_vbox;
 
@@ -87,10 +89,13 @@ class GamePreferencesDialog
     std::list<Gtk::ComboBoxText *> player_types;
     std::list<Gtk::Entry *> player_names;
 
+    GameOptionsDialog *game_options_dialog;
+
     void add_player(const Glib::ustring &type, const Glib::ustring &name);
     void on_add_player_clicked();
     void on_random_map_toggled();
     void on_map_size_changed();
+    void on_difficulty_changed();
     void on_start_game_clicked();
     void on_edit_options_clicked();
     void on_player_type_changed();
@@ -101,8 +106,15 @@ class GamePreferencesDialog
     void on_hills_random_toggled();
     void on_mountains_random_toggled();
     void on_cities_random_toggled();
-    void on_ruins_random_toggled();
-    void on_temples_random_toggled();
+    void on_map_chosen();
+    bool is_beginner();
+    bool is_intermediate();
+    bool is_advanced();
+    bool is_greatest();
+    void update_difficulty_combobox();
+    void update_difficulty_rating();
+    bool scan_players(std::string tag, XML_Helper* helper);
+    GameParameters load_map_parameters;
 };
 
 #endif
