@@ -390,9 +390,11 @@ create_and_dump_scenario(const std::string &file, const GameParameters &g)
 
     // now fill in some map information
     creator.setMapTiles(g.tile_theme);
+    creator.setShieldset(g.shield_theme);
+    creator.setCityset(g.city_theme);
     creator.setNoCities(g.map.cities);
     creator.setNoRuins(g.map.ruins);
-    creator.setNoTemples(g.map.temples);
+    creator.setNoTemples(4);
 
     // terrain: the scenario generator also accepts input with a sum of
     // more than 100%, so the thing is rather easy here
@@ -1267,12 +1269,16 @@ void GameWindow::on_group_toggled(Gtk::ToggleButton *toggle)
 {
   if (toggle->sensitive() == false)
     return;
-  if (toggle->get_active() == false)
-    currently_selected_stack->ungroup();
-  else
+  bool active = toggle->get_active();
+      
+  clear_army_buttons();
+  if (active)
     currently_selected_stack->group();
+  else
+    currently_selected_stack->ungroup();
+
+  on_stack_info_changed(currently_selected_stack);
   game->recalculate_moves_for_stack(currently_selected_stack);
-  update_army_buttons();
 }
 
 bool GameWindow::on_army_button_event(GdkEventButton *e,
