@@ -127,6 +127,7 @@ class GameWindow: public sigc::trackable
     // the button control panel
     Gtk::Button *next_movable_button;
     Gtk::Button *center_button;
+    Gtk::Button *diplomacy_button;
     Gtk::Button *defend_button;
     Gtk::Button *park_button;
     Gtk::Button *deselect_button;
@@ -134,6 +135,14 @@ class GameWindow: public sigc::trackable
     Gtk::Button *move_button;
     Gtk::Button *move_all_button;
     Gtk::Button *end_turn_button;
+    Gtk::Button *nw_keypad_button;
+    Gtk::Button *n_keypad_button;
+    Gtk::Button *ne_keypad_button;
+    Gtk::Button *e_keypad_button;
+    Gtk::Button *w_keypad_button;
+    Gtk::Button *sw_keypad_button;
+    Gtk::Button *s_keypad_button;
+    Gtk::Button *se_keypad_button;
 
     Stack *currently_selected_stack;
     std::auto_ptr<ArmyInfoTip> army_info_tip;
@@ -174,6 +183,8 @@ class GameWindow: public sigc::trackable
     void on_gold_report_activated();
     void on_production_report_activated();
     void on_winning_report_activated();
+    void on_diplomacy_report_activated();
+    void on_diplomacy_button_clicked();
 
     void on_fullscreen_activated();
     void on_preferences_activated();
@@ -217,10 +228,13 @@ class GameWindow: public sigc::trackable
     void on_ruin_searched(Ruin *ruin, Stack *s, Reward *reward);
     void on_sage_visited(Ruin *ruin, Stack *s);
     void on_ruin_rewarded(Reward_Ruin *reward);
-    void on_fight_started(Fight &fight);
+    void on_fight_started(Fight &fight, bool intense_combat);
     void on_ruinfight_started(Stack *attackers, Stack *defenders);
     void on_ruinfight_finished(Fight::Result result);
     bool on_hero_offers_service(Player *player, Hero *hero, City *city, int gold);
+    bool on_enemy_offers_surrender(int numEnemies);
+    void on_surrender_answered (bool accepted);
+    bool on_stack_considers_treachery (Player *me, Stack *stack, Player *them, Vector<int> pos);
     bool on_temple_searched(bool hasHero, Temple *temple, int blessCount);
     void on_quest_assigned(Hero *hero, Quest *quest);
     CityDefeatedAction on_city_defeated(City *city, int gold);
@@ -247,6 +261,7 @@ class GameWindow: public sigc::trackable
     void show_map_tip(Glib::ustring msg, MapTipPosition pos);
     void on_city_looted(City *city, int gold);
     void hide_map_tip();
+    void update_diplomacy_button (bool proposals_present);
 
     void setup_game(std::string file_path);
     void setup_signals();
@@ -258,6 +273,8 @@ class GameWindow: public sigc::trackable
 public:
     // not part of the API, but for surface_attached_helper
     void on_sdl_surface_changed();
+    std::vector<Glib::RefPtr<Gdk::Pixbuf> > d_button_images;
+    std::vector<Glib::RefPtr<Gdk::Pixbuf> > d_arrow_images;
     bool d_quick_fights; //do we speed up fights for this player's turn?
 };
 
