@@ -172,10 +172,19 @@ void HistoryReportDialog::generatePastEventlists()
 		case History::HERO_KILLED_IN_BATTLE:
 		case History::HERO_KILLED_SEARCHING:
 		case History::HERO_CITY_WON:
+		case History::HERO_FINDS_ALLIES:
+		case History::PLAYER_VANQUISHED:
+		case History::DIPLOMATIC_TREACHERY:
+		case History::DIPLOMATIC_WAR:
+		case History::DIPLOMATIC_PEACE:
 		  (*hit[id])->setPlayer(*pit);
 		  elist->push_back(*hit[id]);
 		  break;
-		default:
+		case History::START_TURN:
+		case History::GOLD_TOTAL:
+		case History::CITY_WON:
+		case History::CITY_RAZED:
+		case History::SCORE:
 		  break;
 		}
 	    }
@@ -434,7 +443,6 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 
   Glib::ustring s = "";
   Gtk::TreeIter i = events_list->append();
-  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 
   switch (event->getType())
     {
@@ -443,6 +451,7 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 	  History_FoundSage *ev;
 	  ev = static_cast<History_FoundSage *>(event);
 	  s = String::ucompose(_("%1 finds a sage!"), ev->getHeroName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 	  break;
 	}
     case History::HERO_EMERGES:
@@ -451,6 +460,7 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 	  ev = static_cast<History_HeroEmerges *>(event);
 	  s = String::ucompose(_("%1 emerges in %2!"), ev->getHeroName(),
 			       ev->getCityName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 	  break;
 	}
     case History::HERO_QUEST_STARTED:
@@ -458,6 +468,7 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 	  History_HeroQuestStarted *ev;
 	  ev = static_cast<History_HeroQuestStarted*>(event);
 	  s = String::ucompose(_("%1 begins a quest!"), ev->getHeroName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 	  break;
 	}
     case History::HERO_QUEST_COMPLETED:
@@ -465,6 +476,7 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 	  History_HeroQuestCompleted *ev;
 	  ev = static_cast<History_HeroQuestCompleted *>(event);
 	  s = String::ucompose(_("%1 finishes a quest!"), ev->getHeroName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 	  break;
 	}
     case History::HERO_KILLED_IN_CITY:
@@ -473,6 +485,7 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 	  ev = static_cast<History_HeroKilledInCity *>(event);
 	  s = String::ucompose(_("%1 is killed in %2!"), ev->getHeroName(),
 			       ev->getCityName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 	  break;
 	}
     case History::HERO_KILLED_IN_BATTLE:
@@ -480,6 +493,7 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 	  History_HeroKilledInBattle *ev;
 	  ev = static_cast<History_HeroKilledInBattle *>(event);
 	  s = String::ucompose(_("%1 is killed in battle!"), ev->getHeroName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 	  break;
 	}
     case History::HERO_KILLED_SEARCHING:
@@ -488,6 +502,7 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 	  ev = static_cast<History_HeroKilledSearching *>(event);
 	  s = String::ucompose(_("%1 is killed while searching!"), 
 			       ev->getHeroName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 	  break;
 	}
     case History::HERO_CITY_WON:
@@ -496,6 +511,54 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 	  ev = static_cast<History_HeroCityWon *>(event);
 	  s = String::ucompose(_("%1 conquers %2!"), ev->getHeroName(), 
 			       ev->getCityName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  break;
+	}
+    case History::PLAYER_VANQUISHED:
+	{
+	  History_PlayerVanquished *ev;
+	  ev = static_cast<History_PlayerVanquished*>(event);
+	  s = String::ucompose(_("%1 is vanquished!"), p->getName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  break;
+	}
+    case History::DIPLOMATIC_PEACE:
+	{
+	  History_DiplomacyPeace *ev;
+	  ev = static_cast<History_DiplomacyPeace*>(event);
+	  Playerlist *pl = Playerlist::getInstance();
+	  Player *opponent = pl->getPlayer(ev->getOpponentId());
+	  s = String::ucompose(_("%1 at peace with %2!"), p->getName(), 
+			       opponent->getName());
+	  break;
+	}
+    case History::DIPLOMATIC_WAR:
+	{
+	  History_DiplomacyWar *ev;
+	  ev = static_cast<History_DiplomacyWar*>(event);
+	  Playerlist *pl = Playerlist::getInstance();
+	  Player *opponent = pl->getPlayer(ev->getOpponentId());
+	  s = String::ucompose(_("%1 at war with %2!"), p->getName(), 
+			       opponent->getName());
+	  break;
+	}
+    case History::DIPLOMATIC_TREACHERY:
+	{
+	  History_DiplomacyTreachery *ev;
+	  ev = static_cast<History_DiplomacyTreachery*>(event);
+	  Playerlist *pl = Playerlist::getInstance();
+	  Player *opponent = pl->getPlayer(ev->getOpponentId());
+	  s = String::ucompose(_("Treachery by %1 on %2!"), p->getName(),
+			       opponent->getName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  break;
+	}
+    case History::HERO_FINDS_ALLIES:
+	{
+	  History_HeroFindsAllies *ev;
+	  ev = static_cast<History_HeroFindsAllies*>(event);
+	  s = String::ucompose(_("%1 finds allies!"), ev->getHeroName());
+	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 	  break;
 	}
     default:
