@@ -117,16 +117,7 @@ void PreferencesDialog::run(Game *game)
 	      {
 		AI_Fast *new_player = new AI_Fast(**i);
 		Player *old_player = *i;
-		std::replace(Playerlist::getInstance()->begin(),
-			     Playerlist::getInstance()->end(),
-			     old_player, dynamic_cast<Player*>(new_player));
-		//point cities to the new owner
-		Citylist *clist = Citylist::getInstance();
-		clist->changeOwnership (old_player, 
-					dynamic_cast<Player*>(new_player));
-		Ruinlist *rlist = Ruinlist::getInstance();
-		rlist->changeOwnership (old_player, 
-					dynamic_cast<Player*>(new_player));
+		Playerlist::getInstance()->swap(old_player, new_player);
 		//disconnect and connect game signals
 		game->addPlayer(new_player);
 	      }
@@ -137,18 +128,7 @@ void PreferencesDialog::run(Game *game)
 	      {
 		RealPlayer *new_player = new RealPlayer(**i);
 		Player *old_player = *i;
-		//now how do i replace it in the playerlist?
-		std::replace(Playerlist::getInstance()->begin(),
-			     Playerlist::getInstance()->end(),
-			     old_player, dynamic_cast<Player*>(new_player));
-		//point cities to the new owner
-		Citylist *clist = Citylist::getInstance();
-		clist->changeOwnership (old_player, 
-					dynamic_cast<Player*>(new_player));
-		//point ruins to the new owner (for hidden ruins)
-		Ruinlist *rlist = Ruinlist::getInstance();
-		rlist->changeOwnership (old_player, 
-					dynamic_cast<Player*>(new_player));
+		Playerlist::getInstance()->swap(old_player, new_player);
 		//disconnect and connect game signals
 		game->addPlayer(new_player);
 		
@@ -157,6 +137,7 @@ void PreferencesDialog::run(Game *game)
 	      ;
 	  }
       }
+    dialog->hide();
 }
 
 void PreferencesDialog::on_show_turn_popup_toggled()
