@@ -20,6 +20,9 @@
 #include <sigc++/trackable.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/image.h>
+#include <gtkmm/treeview.h>
+#include <gtkmm/liststore.h>
+#include <gtkmm/treemodelcolumn.h>
 
 #include "../ruinmap.h"
 #include "../player.h"
@@ -35,18 +38,34 @@ class SageDialog: public sigc::trackable
 
     void set_parent_window(Gtk::Window &parent);
 
-    void run();
+    Reward *run();
     
  private:
     std::auto_ptr<Gtk::Dialog> dialog;
     std::auto_ptr<RuinMap> ruinmap;
 
+    Gtk::TreeView *rewards_treeview;
+
+    class RewardsColumns: public Gtk::TreeModelColumnRecord {
+    public:
+	RewardsColumns() 
+        { add(name); add(reward);}
+	
+	Gtk::TreeModelColumn<Glib::ustring> name;
+	Gtk::TreeModelColumn<Reward *> reward;
+    };
+    const RewardsColumns rewards_columns;
+    Glib::RefPtr<Gtk::ListStore> rewards_list;
+
     Gtk::Image *map_image;
     
     Hero *hero;
     Ruin *ruin;
 
+    std::list<Reward*> common_rewards;
     void on_map_changed(SDL_Surface *map);
+    void addReward(Reward *reward);
+    Reward *grabSelectedReward();
 };
 
 #endif
