@@ -86,9 +86,6 @@ int main(int argc, char* argv[])
                 //cout << _("-g,      --ggz              Run game in GGZ mode") << endl;
 #endif
 		cout << endl << endl;
-#if 0
-                cout << _("Please send bug reports to ulf82@users.sf.net") << endl << endl;
-#endif
                 exit(0);
             }
         }
@@ -107,6 +104,10 @@ int main(int argc, char* argv[])
 
     // Check if armysets are in the path (otherwise exit)
     File::scanArmysets();
+    File::scanTilesets();
+    File::scanShieldsets();
+    File::scanCitysets();
+
 
     kit.start_main_loop();
     
