@@ -17,7 +17,7 @@
 #include <iostream>
 #include "tileset.h"
 
-Maptile::Maptile(TileSet* tileSet, int x, int y, Uint32 type, TileStyle *tileStyle)
+Maptile::Maptile(Tileset* tileSet, int x, int y, Uint32 type, TileStyle *tileStyle)
     :d_index(type), d_building(NONE) 
 {
     d_tileSet = tileSet;
@@ -47,7 +47,14 @@ Uint32 Maptile::getMoves() const
     else if (d_building == Maptile::BRIDGE)
         return 1;
 
-    return (*d_tileSet)[d_index]->getMoves();
+    Tile *tile = (*d_tileSet)[d_index];
+    if (tile->getType() == Tile::WATER)
+      {
+	// if we're sailing and we're not on shore, then we move faster
+	if (d_tileStyle->getType() == TileStyle::INNERMIDDLECENTER)
+	  return tile->getMoves() / 2;
+      }
+    return tile->getMoves();
 }
 
 SDL_Color Maptile::getColor() const
