@@ -167,7 +167,7 @@ void Path::recalculate (Stack* s)
   return;
 }
 
-Uint32 Path::calculate (Stack* s, Vector<int> dest)
+Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
 {
     int mp;
     Vector<int> start = s->getPos();
@@ -177,11 +177,11 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest)
     int width = GameMap::getWidth();
     int height = GameMap::getHeight();
     d_bonus = s->calculateMoveBonus();
-    if (isBlocked(s, dest.x, dest.y, dest.x, dest.y))
-      {
-	s->setMovesExhaustedAtPoint(0);
-        return 0;
-      }
+    //if (isBlocked(s, dest.x, dest.y, dest.x, dest.y))
+      //{
+	//s->setMovesExhaustedAtPoint(0);
+        //return 0;
+      //}
     
     // Some notes concerning the path finding algorithm. The algorithm
     // uses two different lists. There is a distance array, which contains how
@@ -251,6 +251,12 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest)
                 if (dsxy < -1)
                     continue; // can't move there anyway
 
+		if (zigzag == false)
+		  {
+		    Vector<int> diff = pos - Vector<int>(sx, sy);
+		    if (diff.x && diff.y)
+		      continue;
+		  }
                 int newDsxy = dxy;
                 mp = pointsToMoveTo(s, pos.x, pos.y, sx, sy);
                 if (mp >= 0)
@@ -281,9 +287,29 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest)
 
     // choose the order in which we process directions so as to favour
     // diagonals over straight lines
-    int diffs[][2] = { {-1, -1}, {-1, 1}, {1, -1}, {1, 1}, {1, 0}, {-1, 0}, {0, -1}, {0, 1} };
+    std::list<Vector<int> > diffs;
+    if (zigzag)
+      {
+	diffs.push_back(Vector<int>(-1, -1));
+	diffs.push_back(Vector<int>(-1, 1));
+	diffs.push_back(Vector<int>(1, -1));
+	diffs.push_back(Vector<int>(1, 1));
+	diffs.push_back(Vector<int>(1, 0));
+	diffs.push_back(Vector<int>(-1, 0));
+	diffs.push_back(Vector<int>(0, -1));
+	diffs.push_back(Vector<int>(0, 1));
+      }
+    else
+      {
+	diffs.push_back(Vector<int>(1, 0));
+	diffs.push_back(Vector<int>(-1, 0));
+	diffs.push_back(Vector<int>(0, -1));
+	diffs.push_back(Vector<int>(0, 1));
+      }
+
     int x = dest.x;
     int y = dest.y;
+
     while (dist > 0)
     {
         Vector<int> *p = new Vector<int>(x,y);
@@ -292,11 +318,11 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest)
         int min = dist;
         int rx = x;
         int ry = y;
-
-        for (int i=0; i<8; i++)
+	for (std::list<Vector<int> >::iterator it = diffs.begin();
+	     it != diffs.end(); it++)
         {
-            int newx = x + diffs[i][0];
-            int newy = y + diffs[i][1];
+            int newx = x + (*it).x;//diffs[i][0];
+            int newy = y + (*it).y;//diffs[i][1];
             if (newx < 0 || newx == width || newy < 0 || newy == height)
                 continue;
 //isBlockedDir is needed to catch crossings from land to sea when not thru a port/city
@@ -317,10 +343,15 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest)
         dist = min;
     }
 
+    //calculate when the waypoints show no more movement possible
     Uint32 pathcount = 0;
+    Uint32 moves_left = s->getGroupMoves();
     for (iterator it = begin(); it != end(); it++)
       {
-	if (s->getGroupMoves() < (Uint32) distance[(*it)->y * width + (*it)->x])
+	Uint32 moves = s->calculateTileMovementCost(**it);
+	if (moves_left >= moves)
+	  moves_left -= moves;
+	else
 	  break;
 	pathcount++;
       }
@@ -381,7 +412,7 @@ bool Path::isBlocked(const Stack* s, int x, int y, int destx, int desty) const
 
         // ...friendly stacks which are too big to merge with...
         if ((s->getPlayer() == target->getPlayer())
-            && (s->size() + target->size() > 8))
+            && (s->size() + target->size() > MAX_STACK_SIZE))
             return true;
     }
 
@@ -401,20 +432,19 @@ bool Path::isBlocked(const Stack* s, int x, int y, int destx, int desty) const
 
 int Path::pointsToMoveTo(const Stack *s, int x, int y, int destx, int desty) const
 {
+  Uint32 moves;
     const Maptile* tile = GameMap::getInstance()->getTile(destx,desty);
     
     if (x == destx && y == desty) //probably shouldn't happen
       return 0;
 
-    // A city on the next square, we _know_ that the city is nice to us
-    if (tile->getBuilding() == Maptile::CITY)
-        return 1;
+    moves = tile->getMoves();
 
     // does everything in the stack have a bonus to move onto this square?
-    if (tile->getMaptileType() & d_bonus)
+    if (tile->getMaptileType() & d_bonus && moves != 1)
         return 2;
 
-    return tile->getMoves();
+    return moves;
 }
 
 // End of file
