@@ -87,6 +87,10 @@ class Playerlist : public std::list<Player*>, public sigc::trackable
           */
         Player* getFirstLiving() const;
         
+
+	/** Replace old_player with new_player everywhere.
+	 */
+	void swap(Player *old_player, Player *new_player);
         
         //! Saves the playerlist. See XML_Helper for further docu.
         bool save(XML_Helper* helper) const;
@@ -99,9 +103,17 @@ class Playerlist : public std::list<Player*>, public sigc::trackable
         //! This signal is emitted when a player has died.
         sigc::signal<void, Player*> splayerDead;
     
-        void calculateWinners();
+        //! This signal is emitted when a surrender is offered
+        sigc::signal<void, Player*> ssurrender;
+    
+	void nextRound(bool diplomacy, bool *surrender_already_offered);
 
 	Uint32 countHumanPlayersAlive();
+	Uint32 countPlayersAlive(); //does not include neutral player
+
+	void randomizeOrder();
+
+        void calculateDiplomaticRankings();
 
     protected:
         // CREATORS
@@ -113,6 +125,12 @@ class Playerlist : public std::list<Player*>, public sigc::trackable
         //! Callback for loading the playerlist.
         bool load(std::string, XML_Helper* helper);
 
+	static bool randomly(const Player *lhs, const Player *rhs);
+
+	//! end of round stuff
+        void calculateWinners();
+	void negotiateDiplomacy();
+
         //static pointers for the singleton
         static Playerlist* s_instance;
         
