@@ -23,6 +23,7 @@
 //#include "FightDialog.h"
 #include "stacklist.h"
 #include "citylist.h"
+#include "portlist.h"
 #include "templelist.h"
 #include "ruinlist.h"
 #include "signpostlist.h"
@@ -178,9 +179,13 @@ bool RealPlayer::stackJoin(Stack* receiver, Stack* joining, bool grouped)
     if ((receiver == 0) || (joining == 0))
         return false;
 
-    if ((receiver->size() + joining->size()) > 8)
+    if ((receiver->size() + joining->size()) > MAX_STACK_SIZE)
         return false;
     
+    Action_Join* item = new Action_Join();
+    item->fillData(receiver, joining);
+    d_actions.push_back(item);
+
     // now if grouped is set to false, ungroup all the receiving stack's armies
     // (by default, only the joining stacks armies will continue to move)
     // Note that the computer player silently ignores the grouped value and always
@@ -194,9 +199,6 @@ bool RealPlayer::stackJoin(Stack* receiver, Stack* joining, bool grouped)
         (*it)->setGrouped(true);
     }
 
-    Action_Join* item = new Action_Join();
-    item->fillData(receiver, joining);
-    d_actions.push_back(item);
 
     joining->clear();    //clear only erases the pointers not the armies
     d_stacklist->flRemove(joining);
@@ -471,7 +473,7 @@ Fight::Result ruinfight (Stack **attacker, Stack **defender)
   hero_strength = (*attacker)->getFirstHero()->getStat(Army::STRENGTH, true);
   monster_strength = (*defender)->getStrongestArmy()->getStat(Army::STRENGTH, true);
   float base_factor = 0.25;
-  float stack_factor = (9.0 - (*attacker)->size()) / 8.0;
+  float stack_factor = ((float)(MAX_STACK_SIZE + 1) - (*attacker)->size()) / (float)MAX_STACK_SIZE;
   float hero_factor = (10.0 - hero_strength) / 5.0;
   float monster_factor;
   if (monster_strength >= 8)
@@ -584,7 +586,6 @@ Fight::Result RealPlayer::stackFight(Stack** attacker, Stack** defender, bool ru
 
     // I suppose, this should be always true, but one can never be sure
     bool attacker_active = *attacker == d_stacklist->getActivestack();
-    Player* pa = (*attacker)->getPlayer();
 
     Fight fight(*attacker, *defender);
 
@@ -1317,13 +1318,16 @@ bool RealPlayer::stackMoveOneStep(Stack* s)
   Uint32 maptype = GameMap::getInstance()->getTile(dest.x,dest.y)->getMaptileType();
   City* to_city = Citylist::getInstance()->getObjectAt(dest.x, dest.y);
   City* on_city = Citylist::getInstance()->getObjectAt(s->getPos().x, s->getPos().y);
+  Port* on_port = Portlist::getInstance()->getObjectAt(s->getPos().x, s->getPos().y);
   bool on_water = (GameMap::getInstance()->getTile(s->getPos().x,s->getPos().y)->getMaptileType() == Tile::WATER);
   bool to_water = (GameMap::getInstance()->getTile(dest.x,dest.y)->getMaptileType() == Tile::WATER);
   bool ship_load_unload = false;
   //here we mark the armies as being on or off a boat
   if (!s->isFlying())
     {
-      if ((on_water && to_city) || (on_city && to_water))
+      if ((on_water && to_city) || 
+	  (on_water && on_port && !to_water) ||
+	  ((on_city || on_port) && to_water))
 	{
 	  ship_load_unload = true;
 	  for (Stack::iterator it = s->begin(); it != s->end(); it++)
@@ -1341,31 +1345,22 @@ bool RealPlayer::stackMoveOneStep(Stack* s)
       for (Stack::iterator it = s->begin(); it != s->end(); it++)
 	(*it)->setInShip(false);
     }
-  needed_moves = GameMap::getInstance()->getTile(dest.x,dest.y)->getMoves();
+
+  //how many moves does the stack need to travel to dest?
+  needed_moves = s->calculateTileMovementCost(dest);
 
   for (Stack::iterator it = s->begin(); it != s->end(); it++)
-    //calculate possible move boni for each army
     {
       if (ship_load_unload)
+	(*it)->decrementMoves((*it)->getMoves());
+      else 
 	{
-	  (*it)->decrementMoves((*it)->getMoves());
-	  continue;
+	  //maybe the army has a natural movement ability
+	  if ((*it)->getStat(Army::MOVE_BONUS) == maptype && needed_moves > 1)
+	    (*it)->decrementMoves(2);
+	  else
+	    (*it)->decrementMoves(needed_moves);
 	}
-      if (to_city != 0)
-	//cities cost one MP
-	{
-	  (*it)->decrementMoves(1);
-	  continue;
-	}
-
-      if ((*it)->getStat(Army::MOVE_BONUS) == maptype)
-	//if army has move bonus, it takes only 2 move points...
-	{
-	  (*it)->decrementMoves(2);
-	  continue;
-	}
-      //else the whole
-      (*it)->decrementMoves(needed_moves);
     }
 
   s->moveOneStep();    //this is only for updating positions etc.
@@ -1382,6 +1377,17 @@ bool RealPlayer::stackMoveOneStep(Stack* s)
   return true;
 }
 
+bool RealPlayer::changeVectorDestination(City *c, Vector<int> dest)
+{
+  bool retval = true;
+  Citylist *cl = Citylist::getInstance();
+  std::list<City*> sources = cl->getCitiesVectoringTo(c);
+  std::list<City*>::iterator it = sources.begin();
+  for (; it != sources.end(); it++)
+    retval &= (*it)->changeVectorDestination(dest);
+  return retval;
+}
+
 bool RealPlayer::vectorFromCity(City * c, Vector<int> dest)
 {
   c->setVectoring(dest);
