@@ -83,6 +83,8 @@ bool Ruinlist::load(std::string tag, XML_Helper* helper)
     //! since the ruin has only now been copied to its final state, we need
     //to register the callback for the occupants here.
     helper->registerTag("stack", sigc::mem_fun(*begin(), &Ruin::load));
+    // same with rewards in ruins
+    helper->registerTag("reward", sigc::mem_fun(*begin(), &Ruin::load));
 
     return true;
 }
@@ -175,3 +177,11 @@ Ruin* Ruinlist::getNearestVisibleRuin(const Vector<int>& pos, int dist)
     return r;
   return NULL;
 }
+
+void Ruinlist::changeOwnership(Player *old_owner, Player *new_owner)
+{
+  for (iterator it = begin(); it != end(); it++)
+    if ((*it).getOwner() == old_owner)
+      (*it).setOwner(new_owner);
+}
+
