@@ -163,7 +163,6 @@ int Stack::getMinTileMoves() const
   GameMap *map = GameMap::getInstance();
   Rectangle bounds = GameMap::get_boundary();
 
-  Path p;
   std::vector<Vector<int> > tiles;
   tiles.push_back(Vector<int>(getPos().x + 1, getPos().y - 1));
   tiles.push_back(Vector<int>(getPos().x,     getPos().y - 1));
@@ -178,7 +177,7 @@ int Stack::getMinTileMoves() const
 
   for (std::vector<Vector<int> >::iterator i = tiles.begin(), end = tiles.end();
        i != end; ++i)
-    if (is_inside(bounds, *i)) // && p.canMoveThere(this, *i))
+    if (is_inside(bounds, *i))
       {
 	int v = map->getTile(i->x, i->y)->getMoves();
 	if (min == -1)
@@ -252,7 +251,7 @@ void Stack::group()
 {
   if (empty())
     return;
-  for (const_iterator it = begin(); it != end(); ++it)
+  for (iterator it = begin(); it != end(); ++it)
     (*it)->setGrouped(true);
   return;
 }
@@ -261,7 +260,7 @@ void Stack::ungroup()
 {
   if (empty())
     return;
-  for (const_iterator it = begin(); it != end(); ++it)
+  for (iterator it = begin(); it != end(); ++it)
     (*it)->setGrouped(false);
   //set first army to be in the group
   (*(begin()))->setGrouped(true);
@@ -309,22 +308,19 @@ int Stack::bless()
   return count;
 }
 
+Uint32 Stack::calculateTileMovementCost(Vector<int> pos) const
+{
+  Maptile* tile = GameMap::getInstance()->getTile(pos);
+  Uint32 moves = tile->getMoves();
+  if (isFlying() && moves > 1)
+    moves = 2;
+  return moves;
+}
+
 bool Stack::enoughMoves() const
 {
   Vector<int> p = **(d_path->begin());
-  Uint32 needed = 0;
-
-  Maptile* tile = GameMap::getInstance()->getTile(p.x, p.y);
-
-  // find out how many MP we need for travelling, first
-  if (tile->getBuilding() == Maptile::CITY)
-    needed = 1;
-  else
-    for (const_iterator it = begin(); it != end(); it++)
-      if ((*it)->getStat(Army::MOVE_BONUS) & tile->getMaptileType())
-	needed = 2;
-  if (needed == 0)
-    needed = tile->getMoves();
+  Uint32 needed = calculateTileMovementCost(p);
 
   // now check if all armies fulfill this requirement
   for (const_iterator it = begin(); it != end(); it++)
@@ -336,7 +332,8 @@ bool Stack::enoughMoves() const
 
 bool Stack::canMove() const
 {
-  int tile_moves = getMinTileMoves(), group_moves = getGroupMoves();
+  int tile_moves = getMinTileMoves();
+  int group_moves = getGroupMoves();
 
   return group_moves > 0 && tile_moves >= 0 && group_moves >= tile_moves;
 }
@@ -616,6 +613,8 @@ bool Stack::armyCompareFightOrder (const Army *lhs, const Army *rhs)
   std::list<Uint32> rhs_fight_order = rhs->getPlayer()->getFightOrder();
   Uint32 lhs_rank = getFightOrder (lhs_fight_order, lhs->getType());
   Uint32 rhs_rank = getFightOrder (rhs_fight_order, rhs->getType());
+  //if (lhs_rank == rhs_rank)
+    //return lhs->getId() < rhs->getId();
   return lhs_rank < rhs_rank; 
 }
 
