@@ -20,6 +20,7 @@
 #include "vector.h"
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
+#include <sstream>
 
 #include "Object.h"
 
@@ -87,9 +88,6 @@ class Stack : public ::Object, public std::list<Army*>, public sigc::trackable
         //! Sets the stack's position to the next item of the internal path
         bool moveOneStep();
 
-        //! Resets the moves of all armies to their maximum
-        void resetMoves();
-
         //! Blesses all armies of the stack (strength +1)
 	//! Returns the number of blessed armies.
         int bless();
@@ -166,6 +164,10 @@ class Stack : public ::Object, public std::list<Army*>, public sigc::trackable
         bool isFlying () const;
         bool hasShip () const;
 
+	//! how much does it cost in movement points for the stack
+	//to move to move onto a tile that has the characteristics of the
+	//tile located at POS. (this is not a distance calculation)
+	Uint32 calculateTileMovementCost(Vector<int> pos) const;
 
         sigc::signal<void, Stack*> sdying;
 
