@@ -24,7 +24,7 @@
 
 class XML_Helper;
 
-/** TileSet is basically an array of tiles (terrain info objects).
+/** Tileset is basically an array of tiles (terrain info objects).
   * 
   * It also contains some functions for loading and some additional items, such
   * as an info string or a name.
@@ -37,14 +37,14 @@ class XML_Helper;
   * release. If it already exists, see there for further info.
   */
 
-class TileSet : public sigc::trackable, public std::vector<Tile*>
+class Tileset : public sigc::trackable, public std::vector<Tile*>
 {
     public:
         /** The constructor.
           * 
           */
-        TileSet(XML_Helper* helper);
-        ~TileSet();
+        Tileset(XML_Helper* helper);
+        ~Tileset();
 
         std::string getSubDir() const {return d_dir;}
         void setSubDir(std::string dir) {d_dir = dir;}
@@ -52,10 +52,10 @@ class TileSet : public sigc::trackable, public std::vector<Tile*>
         std::string getName() const {return d_name;}
 
         //! Returns the info string of the tileset
-        std::string getInfo() const {return __(d_info);}
+        std::string getInfo() const {return d_info;}
 
         //! Returns the tilesize of the tileset.
-        int getTileSize() const {return d_tileSize;}
+        Uint32 getTileSize() const {return d_tileSize;}
 
         //! Returns the index to standard terrain type
         Uint32 getIndex(Tile::Type type) const;
@@ -75,7 +75,7 @@ class TileSet : public sigc::trackable, public std::vector<Tile*>
         // DATA
         std::string d_name;
         std::string d_info;
-        int d_tileSize;
+        Uint32 d_tileSize;
         std::string d_dir;
         typedef std::map<Uint32, TileStyle*> TileStyleIdMap;
         TileStyleIdMap d_tilestyles;
